package net.pricefx.common.api;

import java.util.EnumSet;
import java.util.HashMap;
import java.util.Map;

public enum FormulaNature implements IFormulaNature {

	DEFAULT(null, "DEFAULT"),

	QUOTE_HEADER("quoteHeader", "QH"), // Header Formula Nature
	QUOTE_PRODUCT_FILTER("quoteProductFilter", "QPF"),
	CONTRACT_TERM_TYPE_FILTER("contractTermTypeFilter", "CTTF"),
	
	CONTRACT("contract", "CT"),
	CONTRACT_HEADER("contractHeader", "CTH"), // Header Formula Nature
	
	REBATE("rebateAgreement", "RBA"),
	REBATE_AGREEMENT_HEADER("rebateAgreementHeader", "RBAH"), // Header Formula Nature
	REBATE_TYPE_FILTER("rebateTypeFilter", "RBTF"),
	
	PA_DATALOAD("paDataLoad", "PADL"),
	PA_QUERY("paQuery", "PAQ"),
	
	LIBRARY("library", "LIB"),
	
	PRODUCT_DETAIL("productDetail", "PD"),
	CUSTOMER_DETAIL("customerDetail", "CD"),
	REBATE_DETAIL("rebateDetail", "RD"),

	CUSTOMER_INPUT_FILTER("customerInputFilter", "CIF"),
	PRODUCT_INPUT_FILTER("productInputFilter", "PIF"),

	QUOTE_ENTITLEMENT_FILTER("quoteEntitlementFilter", "QEF"),
	CONTRACT_ENTITLEMENT_FILTER("contractEntitlementFilter", "CTEF"),
	REBATE_AGREEMENT_ENTITLEMENT_FILTER("rebateAgreementEntitlementFilter", "RBAEF"),
	
	CALCULATION_FLOW("calculationFlow", "CF"),

	INLINE_DETAILS_VIEW("inlineDetailsView", "IDV"),
	
	MATRIX("matrix", "MX"),

	REBATE_AGREEMENT_TEMPLATE("rebateAgreementTemplate", "RAT"),
	
    MODEL("model", "M"),

	CREATION_WORKFLOW("creationWorkflow", "CWF"),

	WORKFLOW_DELEGATION_USER_FILTER("wdUserFilter", "WDUF"),

	QUOTES_MASS_UPDATE("quotesMassUpdate", "QMU"),

	CONTRACTS_MASS_UPDATE("contractsMassUpdate", "CTMU"),

	CLAIM("claim", "CL"),

	CO_HEADER("coHeader","COH"),

	EVENT_HOOK("eventHook", "EH"),
	
	DEALPLAN_HEADER("dealPlanHeader", "DPH"),

	DIST_PACALC("distPACalc", "DPA"),

	MODEL_CALCULATION("model_calculation", "MCC"),
	MODEL_EVALUATION("model_evaluation", "MCE"),

	;

	private static final Map<String,FormulaNature> lookupViaDBValue = new HashMap<String,FormulaNature>(FormulaNature.values().length + 1, 1);
	private static final Map<String,FormulaNature> lookupViaRestApiValue = new HashMap<String,FormulaNature>(FormulaNature.values().length + 1, 1);

	private String dbValue;
    private String restApiValue;

	static {
	    for(FormulaNature nature : EnumSet.allOf(FormulaNature.class)) { 
	         lookupViaDBValue.put(nature.dbValue, nature);
	    }
	    
	    for(FormulaNature nature : EnumSet.allOf(FormulaNature.class)){
	    	lookupViaRestApiValue.put(nature.restApiValue, nature);
	    }
	}	
	
    public static FormulaNature getViaDBValue(String dbValue) { 
       	return lookupViaDBValue.get(dbValue); 
    }
	
    public static FormulaNature getViaRestApiValue(String restApiValue) { 
       	return lookupViaRestApiValue.get(restApiValue); 
    }
    
	private FormulaNature(String dbValue, String restApiValue) {
		this.dbValue = dbValue;
		this.restApiValue = restApiValue;
	}

	public String getDbValue() {
		return dbValue;
	}

	public String getRestApiValue() {
		return restApiValue;
	}

	public static boolean isHeaderNature(FormulaNature n) {
		if(QUOTE_HEADER.equals(n) || CONTRACT_HEADER.equals(n) || REBATE_AGREEMENT_HEADER.equals(n)) {
			return true;
		} else {
			return false;
		}
	}
}
