package net.pricefx.common.api;


/**
 * This file contains all field names used in the JSON messages sent back and
 * forth This file needs to be kept manually in sync for both subprojects
 *
 * It also is just a helper and definitively not a assurance that the field
 * names match Especially as most of the field names are derived from the actual
 * Java property names by the JSON mapper
 *
 *
 */
public class PriceFxInterface {

	// message format
	public static final String DATA_BLOCK = "data";
	public static final String HTTP_LOCALE_PARAM_NAME = "dataLocale";
	public static final String HTTP_ONCONFLICT_PARAM_NAME = "onConflict";
	public static final String HTTP_ONCONFLICT_VALIDATION_ERROR = "validationError";

	public static final String GLOBALEXTENSION_PREFIX = "GLOBAL.";

	public static final String FIELD_ATTRIBUTE_PREFIX = "attribute";
	public static final String FIELD_ATTRIBUTE_EXTENSION_PREFIX = "attributeExtension";
	public static final int FIELD_ATTRIBUTE_COUNT_LO = 30;
	public static final int FIELD_ATTRIBUTE_COUNT_HI = 100;

	public static final String FIELD_ERRORMSG = "errorMessage";

	public static final String FIELD_VALUE_DELIM = "^^^";
	public static final String GLOBALEXT_SEPARATOR = "__";
	public static final String ATTRIBUTE_EXTENSION_SEPARATOR = "___";
	public static final String PRODUCT_MASTER_SUBFILTER = "ProductMaster";
	public static final String CUSTOMER_MASTER_SUBFILTER = "CustomerMaster";

	// datamart validation regex
	public static final String DM_IDENTIFIER_VALIDATION_REGEX = "[a-zA-Z]+[\\w_]*";
	//public static final String DM_LABEL_VALIDATION_REGEX = "[a-zA-Z]+[\\w|-| ]*";
	public static final String DM_LABEL_VALIDATION_REGEX = ".*";

	public static final String JWT_COOKIE_NAME = "X-PriceFx-jwt";
	public static final String CSRF_TOKEN_COOKIE_NAME = "X-PriceFx-Csrf-Token";
	public static final String CSRF_TOKEN_HEADER_NAME = CSRF_TOKEN_COOKIE_NAME;

	public static final String TRACE_MARKER = "__TRACE__";
	public static final String ROW_MARKER = "__ROW__";

	public static final String LINKREF_MARKER = "<ref/>";

	/**
	 *
	 * COMMANDS
	 *
	 */
	// general
	public static final String CMD_LOGIN = "login";		//only API V1
	public static final String CMD_INIT = "init";		//only API V2
	public static final String CMD_LOGOUT = "logout";	//only API V1
	public static final String CMD_API = "api";			//swagger API definition
	public static final String CMD_PING = "ping";
	public static final String CMD_ALIVE = "alive";
	public static final String CMD_DIRECTACTION = "directaction";
	public static final String CMD_EXCELCLIENT = "excelclient";
	public static final String CMD_EXPORT_TO_EXCEL = "exporttoexcel";
	public static final String CMD_REDIRECT = "redirect";
	public static final String CMD_LINK_REF = "linkref";
	public static final String CMD_LINK_TEMPFILE = "linktempfile";
	public static final String CMD_IMPORTFILE = "importfile";

	//SAML support
	public static final String CMD_SAML = "saml";

	//O365 login
	public static final String CMD_O365 = "o365auth";

	//Platform connection
	public static final String CMD_PLATFORM_LOGIN = "platform.login";
	public static final String CMD_PLATFORM_GOTO = "platform.goto";

	//E-Signature support
	public static final String CMD_ESIGNATURE_AUTH = "signature.auth";
	public static final String CMD_ESIGNATURE_STATUS = "signature.status";
	public static final String CMD_ESIGNATURE_CALLBACK = "signature.callback";

	//used for V2 auth model
	public static final String CMD_TOKEN = "token";
	public static final String CMD_LOCKER = "locker";
	public static final String HTTP_HEADER_PRICEFXKEY = "PriceFx-Key";
	public static final String HTTP_HEADER_PRICEFXTFA = "PriceFx-TFA";
	public static final String HTTP_HEADER_PRICEFXNODE = "PriceFx-Node";

	public static final String HTTP_HEADER_PRICEFXNODEAUTHTOKEN = "PriceFx-NodeAuthToken";
	public static final String HTTP_HEADER_PRICEFXNODEAUTHUSER = "PriceFx-NodeAuthUser";
	public static final String HTTP_URL_ONETIMEAUTHTOKEN = "OTAuthToken";

	public static final String HTTP_HEADER_PRICEFX_SOURCE_TRANSACTION_ID = "PriceFx-sourceTransactionId";

	// Highcharts
	public static final String CMD_HIGHCHARTS_EXPORTSERVER = "hcexportserver";

	// system
	public static final String CMD_HOSTINFO = "system$hostinfo";
	public static final String CMD_DBINFO = "system$dbinfo";
	public static final String CMD_RELOADROLES = "system$reloadroles";
	public static final String CMD_UPDATEDSREF = "system$updatedsref";
	public static final String CMD_LOGLEVEL = "system$loglevel";
	public static final String CMD_UNBANALLUSERS = "system$unbanusers";
	public static final String CMD_MIGRATETOS3 = "system$migratetos3";
	public static final String CMD_PURGESTALEIMPEXP = "system$PurgeStaleImportExports";
	public static final String CMD_READONLYMODE = "system$readonlymode";
	public static final String CMD_RELOADPARTITIONCONFIG = "system$reloadpartitionconfig";
	public static final String CMD_RESTART = "system$restart";
	public static final String CMD_WRITENAMESTOWORKFLOWS = "system$writeNamesToWorkflows";

	public static final String CMD_READINESS_PROBE = "system$readinessprobe";
	public static final String CMD_LIVINESS_PROBE = "system$livinessprobe";
	public static final String CMD_STARTUP_PROBE = "system$startupprobe";

	public static final String CMD_CLUSTER = "system$cluster";
	public static final String SUBCMD_CLUSTER_NODES = "nodes";
	public static final String SUBCMD_CLUSTER_STATUS = "status";
	public static final String SUBCMD_CLUSTER_PARTITIONS = "partitions";
	public static final String SUBCMD_CLUSTER_UPDATENODE = "updatenode";
	public static final String SUBCMD_CLUSTER_UNLOCK = "unlock";

	public static final String CMD_DBMIGRATIONS_FETCH = "system$dbmigrationmanager.fetch";
	public static final String CMD_DBMIGRATIONS_RESOLVE = "system$dbmigrationmanager.resolve";
	public static final String CMD_DBMIGRATIONS_BASELINE = "system$dbmigrationmanager.baseline";
	public static final String CMD_DBMIGRATIONS_FETCHSCHEMAS = "system$dbmigrationmanager.fetchschemas";
	public static final String CMD_DBMIGRATIONS_RECOMPUTE = "system$dbmigrationmanager.recompute";
	public static final String CMD_DBMIGRATIONS_APPLY = "system$dbmigrationmanager.apply";
	public static final String CMD_DBMIGRATIONS_REPAIR = "system$dbmigrationmanager.repair";
	public static final String CMD_DBMIGRATIONS_CANCELALL = "system$dbmigrationmanager.cancelall";
	public static final String CMD_DBMIGRATIONS_SHOWPRECLI = "system$dbmigrationmanager.showprecli";
	public static final String CMD_DBMIGRATIONS_VALIDATE = "system$dbmigrationmanager.validate";
	public static final String CMD_DBMIGRATIONS_VALIDATIONRESULTS = "system$dbmigrationmanager.validationresults";

	public static final String CMD_SERVERMIGRATIONS_FETCH = "system$servermigrationmanager.fetch";
	public static final String CMD_SERVERMIGRATIONS_RESOLVE = "system$servermigrationmanager.resolve";
	public static final String CMD_SERVERMIGRATIONS_BASELINE = "system$servermigrationmanager.baseline";
	public static final String CMD_SERVERMIGRATIONS_RECOMPUTE = "system$servermigrationmanager.recompute";
	public static final String CMD_SERVERMIGRATIONS_APPLY = "system$servermigrationmanager.apply";
	public static final String CMD_SERVERMIGRATIONS_REPAIR = "system$servermigrationmanager.repair";
	public static final String CMD_SERVERMIGRATIONS_CANCELALL = "system$servermigrationmanager.cancelall";
	public static final String CMD_SERVERMIGRATIONS_VALIDATE = "system$servermigrationmanager.validate";
	public static final String CMD_SERVERMIGRATIONS_VALIDATIONRESULTS = "system$servermigrationmanager.validationresults";

	// heatbeat
	public static final String CMD_HEARTBEAT_FETCHTASKS = "heartbeat.fetchtasks";
	public static final String CMD_HEARTBEAT_FORCECANCELTASK = "heartbeat.forcecanceltask";
	public static final String CMD_HEARTBEAT_FAILTASK = "heartbeat.failtask";

	// log file viewing
	public static final String CMD_VIEWLOG = "viewlog";
	public static final String CMD_VIEWPERFLOG = "viewperflog";
    public static final String CMD_SERVELOG = "servelog";
    public static final String CMD_SERVEPERFLOG = "serveperflog";
    public static final String CMD_STREAMLOG = "streamlog";
    public static final String CMD_STREAMPERFLOG = "streamperflog";

	// admin
	public static final String CMD_FETCHEMAILTASKS = "admin.fetchemailtasks";
	public static final String CMD_FETCHJST = "admin.fetchjst";
	public static final String CMD_CANCELJST = "admin.canceljst";
	public static final String CMD_FETCH_HOOK_EVENTS = "admin.fetchhookevents";
	public static final String CMD_PARSEFMD = "admin.parseFederationMetaData";
	public static final String CMD_GENERATEFMD = "admin.generateFederationMetaData";

	// data source
	public static final String CMD_FETCH = "fetch";
	public static final String CMD_ADD = "add";
	public static final String CMD_UPDATE = "update";
	public static final String CMD_DELETE = "delete";
	public static final String CMD_DELETEASYNC = "delete.async";
	public static final String CMD_LOADDATA = "loaddata";
	public static final String CMD_TRUNCATE = "truncate";
	public static final String CMD_RESETCOLUMN = "resetcolumn";
	public static final String CMD_MASSEDIT = "massedit";
	public static final String CMD_INTEGRATE = "integrate";
	public static final String CMD_GETDATASOURCES = "getdatasources";
	public static final String CMD_FETCHFILTERNODES = "fetchfilternodes";

	public static final String CMD_GRAPHQL = "graphql";
	public static final String CMD_GRAPHIQL = "graphiql";

	//dashboard
	public static final String CMD_DASHBOARD_FETCHCATEGORIES = "dashboard.fetchCategories";
	public static final String CMD_DASHBOARD_FETCH = "dashboard.fetch";
	public static final String CMD_DASHBOARD_EXECUTE = "dashboard.execute";
	public static final String CMD_DASHBOARD_ADDPORTLETS = "dashboard.addportlets";

	//todo items
	public static final String CMD_TODO_FETCH = "todomanager.fetch";
	public static final String CMD_TODO_ADD = "todomanager.add";
	public static final String CMD_TODO_UPDATE = "todomanager.update";

	//managers
	public static final String CMD_FM_CHECK = "formulamanager.check";
	public static final String CMD_FM_COPY = "formulamanager.copy";
	public static final String CMD_FM_DELETE = "formulamanager.delete";
	public static final String CMD_FM_EXECUTE = "formulamanager.execute";
	public static final String CMD_FM_EXECUTEFORMULA = "formulamanager.executeformula";
	public static final String CMD_FM_EXECUTEFORMULASVC = "formulamanager.executeformulaservice";
	public static final String CMD_FM_FETCH = "formulamanager.fetch";
	public static final String CMD_FM_PARAMS = "formulamanager.params";
	public static final String CMD_FM_PARAMSEXT = "formulamanager.paramsext";
	public static final String CMD_FM_UPDATE = "formulamanager.update";
	public static final String CMD_FM_GETDEFAULT = "formulamanager.getdefault";
	public static final String CMD_FM_SETDEFAULT = "formulamanager.setdefault";
	public static final String CMD_FM_SETRBTFILTERDEFAULT = "formulamanager.setrbtfilterdefault";
	public static final String CMD_FM_GETRBTFILTERDEFAULT = "formulamanager.getrbtfilterdefault";
	public static final String CMD_FM_GETHDEFAULT = "formulamanager.getheaderdefault";
	public static final String CMD_FM_SETHDEFAULT = "formulamanager.setheaderdefault";
	public static final String CMD_FM_GETNAMES = "formulamanager.getnames";
	public static final String CMD_FM_TESTEXEC = "formulamanager.testexec";
	public static final String CMD_FM_DEBUG = "formulamanager.debug";
	public static final String CMD_FM_TESTPARAMS = "formulamanager.testparams";
	public static final String CMD_FM_LIBMETHODS = "formulamanager.librarymethods";
	public static final String CMD_FM_LIBRARIES = "formulamanager.libraries";
	public static final String CMD_FM_GETELEMENTNAMES = "formulamanager.getelementnames";

	public static final String CMD_WFBM_CHECK = "workflowbuildermanager.check";
	public static final String CMD_WFBM_COPY = "workflowbuildermanager.copy";
	public static final String CMD_WFBM_DELETE = "workflowbuildermanager.delete";
	public static final String CMD_WFBM_FETCH = "workflowbuildermanager.fetch";
	public static final String CMD_WFBM_UPDATE = "workflowbuildermanager.update";
	public static final String CMD_WFBM_TESTEXEC = "workflowbuildermanager.testexec";

	public static final String CMD_WFM_FETCH = "workflowsmanager.fetch";
	public static final String CMD_WFM_FETCHFILTEREDBYAPPROVABLE = "workflowsmanager.fetchfilteredbyapprovable";
	public static final String CMD_WFM_FETCHDETAILS = "workflowsmanager.fetchdetails";
	public static final String CMD_WFM_FETCHDETAILSVIAAPPROVABLE = "workflowsmanager.fetchdetailsviaapprovable";
	public static final String CMD_WFM_FETCHWFADMINAWARE = "workflowsmanager.fetchwfadminaware";
	public static final String CMD_WFM_FETCHWITHOUTUSERFILTERING = "workflowsmanager.fetchwithoutuserfiltering";
	public static final String CMD_WFM_ADDAPPROVER = "workflowsmanager.addapprover";
	public static final String CMD_WFM_ADDWATCHER = "workflowsmanager.addwatcher";
	public static final String CMD_WFM_APPROVE = "workflowsmanager.approve";
	public static final String CMD_WFM_WITHDRAW = "workflowsmanager.withdraw";
	public static final String CMD_WFM_DENY = "workflowsmanager.deny";

	// creation worklow mgr
	public static final String CMD_CWF_FETCH_PENDING = "creationworkflowmanager.fetchpending";

	public static final String CMD_WD_ADD = "workflowdelegationmanager.add";
	public static final String CMD_WD_ENDDATE = "workflowdelegationmanager.enddate";
	public static final String CMD_WD_DELETE = "workflowdelegationmanager.delete";
	public static final String CMD_WD_UPDATE = "workflowdelegationmanager.update";
	public static final String CMD_WD_FETCH = "workflowdelegationmanager.fetch";
	public static final String CMD_WD_CHECKDATES = "workflowdelegationmanager.checkdates";
	public static final String CMD_WD_FETCHUSERS = "workflowdelegationmanager.fetchusers";

	public static final String CMD_AM_FETCHROLES = "accountmanager.fetchroles";
	public static final String CMD_AM_FETCHUSERS = "accountmanager.fetchusers";
	public static final String CMD_AM_FETCHGROUPS = "accountmanager.fetchgroups";
	public static final String CMD_AM_FETCHBUSINESSROLES = "accountmanager.fetchbusinessroles";
	public static final String CMD_AM_ASSIGNROLE = "accountmanager.assignrole";
	public static final String CMD_AM_ASSIGNBUSINESSROLE = "accountmanager.assignbusinessrole";
	public static final String CMD_AM_ASSIGNGROUP = "accountmanager.assigngroup";
	public static final String CMD_AM_DELETEGROUP = "accountmanager.deletegroup";
	public static final String CMD_AM_DELETEBUSINESSROLE = "accountmanager.deletebusinessrole";
	public static final String CMD_AM_CHANGEPWD = "accountmanager.changepassword";
	public static final String CMD_AM_COPYROLES = "accountmanager.copyroles";
	public static final String CMD_AM_COPYUSER = "accountmanager.copyuser";
	public static final String CMD_AM_SENDQR = "accountmanager.sendqr";
	public static final String CMD_AM_AUDIT = "accountmanager.audit";
	public static final String CMD_AM_FETCHXLS = "accountmanager.fetchXls";
	public static final String CMD_AM_GETONETIMETOKEN = "accountmanager.getonetimetoken";
	public static final String CMD_AM_GETJWT = "accountmanager.getjsonwebtoken";

	public static final String CMD_KV_CREATETABLE = "kvservice.createtable";
	public static final String CMD_KV_LISTTABLES = "kvservice.listtables";
	public static final String CMD_KV_DROPTABLE = "kvservice.droptable";
	public static final String CMD_KV_PUTKEY = "kvservice.putkey";
	public static final String CMD_KV_FETCHKEY = "kvservice.fetchkey";
	public static final String CMD_KV_FETCH = "kvservice.fetch";
	public static final String CMD_KV_LOADDATA = "kvservice.loaddata";

	public static final String CMD_PREFM_FETCHALL = "prefmanager.fetchAll"; // PFCD-1588 - EC backward compatibility
	public static final String CMD_PREFM_FETCHDEFAULT = "prefmanager.fetchDefault";
	public static final String CMD_PREFM_FETCH = "prefmanager.fetch";
	public static final String CMD_PREFM_ADDORUPDATE = "prefmanager.addorupdate";
	public static final String CMD_PREFM_DELETE = "prefmanager.delete";
	public static final String CMD_PREFM_BATCHDELETE = "prefmanager.batchdelete";

	public static final String CMD_PM_DELETE = "system$partitionmanager.delete";
	public static final String CMD_PM_ADD = "system$partitionmanager.add";
	public static final String CMD_PM_UPDATE = "system$partitionmanager.update";
	public static final String CMD_PM_FETCHGLOBALCONFIGURATION = "partitionmanager.fetchglobalconfiguration";

	public static final String CMD_APIM_DELETE = "system$apikeymanager.delete";
	public static final String CMD_APIM_ADD = "system$apikeymanager.add";
	public static final String CMD_APIM_UPDATE = "system$apikeymanager.update";

	public static final String CMD_CWM_CONFIGURE = "configurationwizard.configure";
	public static final String CMD_CWM_EXECUTE = "configurationwizard.execute";

	public static final String CMD_BPM_DELETE = "boundpartitionmanager.delete";
	public static final String CMD_BPM_ADD = "boundpartitionmanager.add";
	public static final String CMD_BPM_UPDATE = "boundpartitionmanager.update";

	public static final String CMD_LTM_DELETE = "lookuptablemanager.delete";
	public static final String CMD_LTM_ADD = "lookuptablemanager.add";
	public static final String CMD_LTM_FETCH = "lookuptablemanager.fetch";
	public static final String CMD_LTM_COPY = "lookuptablemanager.copy";
	public static final String CMD_LTM_UPDATE = "lookuptablemanager.update";
	public static final String CMD_LTM_RESETCOLUMN = "lookuptablemanager.resetcolumn";
	public static final String CMD_LTM_FINDREFERENCES = "lookuptablemanager.findref";
	public static final String CMD_LTM_MASSEDIT = "lookuptablemanager.massedit";
	public static final String CMD_LTM_INTEGRATE = "lookuptablemanager.integrate";
	public static final String CMD_LTM_LOADDATA = "lookuptablemanager.loaddata";

	public static final String CMD_MPLM_DELETE = "manualpricelistmanager.delete";
	public static final String CMD_MPLM_ADD = "manualpricelistmanager.add";
	public static final String CMD_MPLM_FETCH = "manualpricelistmanager.fetch";
	public static final String CMD_MPLM_COPY = "manualpricelistmanager.copy";
	public static final String CMD_MPLM_UPDATE = "manualpricelistmanager.update";
	public static final String CMD_MPLM_RESETCOLUMN = "manualpricelistmanager.resetcolumn";
	public static final String CMD_MPLM_FINDREFERENCES = "manualpricelistmanager.findref";
	public static final String CMD_MPLM_MASSEDIT = "manualpricelistmanager.massedit";
	public static final String CMD_MPLM_INTEGRATE = "manualpricelistmanager.integrate";
	public static final String CMD_MPLM_CALCULATE = "manualpricelistmanager.calculate";

	public static final String CMD_PLM_ADD = "pricelistmanager.add";
	public static final String CMD_PLM_DELETE = "pricelistmanager.delete";
	public static final String CMD_PLM_FETCH = "pricelistmanager.fetch";
	public static final String CMD_PLM_SUMMARIZE = "pricelistmanager.summarize";
	public static final String CMD_PLM_PARAMS = "pricelistmanager.params";
	public static final String CMD_PLM_PARAMVALUES = "pricelistmanager.paramvalues";
	public static final String CMD_PLM_UPDATE = "pricelistmanager.update";
	public static final String CMD_PLM_SUBMIT = "pricelistmanager.submit";
	public static final String CMD_PLM_REVOKE = "pricelistmanager.revoke";
	public static final String CMD_PLM_PREVIEW = "pricelistmanager.preview";
	public static final String CMD_PLM_CANCEL = "pricelistmanager.cancel";
	public static final String CMD_PLM_FETCHDOCX = "pricelistmanager.fetchdocx";
	public static final String CMD_PLM_FETCHXLS = "pricelistmanager.fetchxls";
	public static final String CMD_PLM_FETCHPDF = "pricelistmanager.fetchpdf";
	public static final String CMD_PLM_MERGE = "pricelistmanager.merge";
	public static final String CMD_PLM_MASSEDIT = "pricelistmanager.massedit";
	public static final String CMD_PLM_CALCULATE = "pricelistmanager.calculate";

	public static final String CMD_PGM_ADD = "pricegridmanager.add";
	public static final String CMD_PGM_DELETE = "pricegridmanager.delete";
	public static final String CMD_PGM_FETCH = "pricegridmanager.fetch";
	public static final String CMD_PGM_SUMMARIZE = "pricegridmanager.summarize";
	public static final String CMD_PGM_PARAMS = "pricegridmanager.params";
	public static final String CMD_PGM_CALCULATE = "pricegridmanager.calculate";
	public static final String CMD_PGM_ACCEPT = "pricegridmanager.accept";
	public static final String CMD_PGM_REJECT = "pricegridmanager.reject";
	public static final String CMD_PGM_PREVIEW = "pricegridmanager.preview";
	public static final String CMD_PGM_UPDATE = "pricegridmanager.update";
	public static final String CMD_PGM_CONVERT2PL = "pricegridmanager.convert2pl";
	public static final String CMD_PGM_MASSEDIT = "pricegridmanager.massedit";
	public static final String CMD_PGM_MASSACTION = "pricegridmanager.massaction";
	public static final String CMD_PGM_MASSACTIONCOUNT = "pricegridmanager.massactioncount";
	public static final String CMD_PGM_COPY = "pricegridmanager.copy";
	public static final String CMD_PGM_FETCHDOCX = "pricegridmanager.fetchdocx";
	public static final String CMD_PGM_FETCHXLS = "pricegridmanager.fetchxls";
	public static final String CMD_PGM_FETCHPDF = "pricegridmanager.fetchpdf";
	public static final String CMD_PGM_CANCEL = "pricegridmanager.cancel";

	public static final String CMD_DCRM_ADD = "dcrmanager.add";
	public static final String CMD_DCRM_ADD_MASS_OP = "dcrmanager.addmassop";
	public static final String CMD_DCRM_FETCH_MASS_OP = "dcrmanager.fetchmassop";
	public static final String CMD_DCRM_DELETE_MASS_OP = "dcrmanager.deletemassop";
	public static final String CMD_DCRM_UPDATE_MASS_OP = "dcrmanager.updatemassop";
	public static final String CMD_DCRM_DELETE = "dcrmanager.delete";
	public static final String CMD_DCRM_FETCH = "dcrmanager.fetch";
	public static final String CMD_DCRM_UPDATE = "dcrmanager.update";
	public static final String CMD_DCRM_PREVIEW = "dcrmanager.preview";
	public static final String CMD_DCRM_SUBMIT = "dcrmanager.submit";
	public static final String CMD_DCRM_STREAM_CHANGES = "dcrmanager.streamChanges";

	public static final String CMD_TM_DELETETREENODE = "treemanager.deletetreenode";
	public static final String CMD_TM_ADDTREENODE = "treemanager.addtreenode";
	public static final String CMD_TM_ADDTREENODECHILDREN = "treemanager.addtreenodechildren";
	public static final String CMD_TM_FETCHTREE = "treemanager.fetchtree";
	public static final String CMD_TM_UPDATETREENODE = "treemanager.updatetreenode";

	public static final String CMD_SIM_DELETE = "simulationmanager.delete";
	public static final String CMD_SIM_FETCH = "simulationmanager.fetch";
	public static final String CMD_SIM_SUMMARIZE = "simulationmanager.summarize";
	public static final String CMD_SIM_UPDATE = "simulationmanager.update";
	public static final String CMD_SIM_CONVERT2PL = "simulationmanager.convert2pl";
	public static final String CMD_SIM_DETAILS = "simulationmanager.details";
	public static final String CMD_SIM_CALCULATE = "simulationmanager.calculate";
	public static final String CMD_SIM_CANCEL = "simulationmanager.cancel";
	public static final String CMD_SIM_FETCHXLS = "simulationmanager.fetchxls";
	public static final String CMD_SIM_MASSEDIT = "simulationmanager.massedit";

	public static final String CMD_CFS_CALCULATE = "cfsmanager.calculate";
	public static final String CMD_CFS_CANCEL = "cfsmanager.cancel";

	public static final String CMD_DATAEXPORT_START = "dataexport.start";
	public static final String CMD_DATAEXPORT_CANCEL = "dataexport.cancel";
	public static final String CMD_DATAEXPORT_DOWNLOAD = "dataexport.download";

	public static final String CMD_DATAARCHIVE_START = "dataarchive.start";
	public static final String CMD_DATAARCHIVE_CANCEL = "dataarchive.cancel";
	public static final String CMD_DATAARCHIVE_DOWNLOAD = "dataarchive.download";

	public static final String CMD_DATAIMPORT_START = "dataimport.start";
	public static final String CMD_DATAIMPORT_CANCEL = "dataimport.cancel";
	public static final String CMD_DATAIMPORT_UPLOAD = "dataimport.upload";

	public static final String CMD_QM_ADDPRODUCTS = "quotemanager.addproducts";
	public static final String CMD_QM_FETCHPRODUCTS = "quotemanager.fetchproducts";
	public static final String CMD_QM_FETCH = "quotemanager.fetch";
	public static final String CMD_QM_FETCHLIST = "quotemanager.fetchlist";
	public static final String CMD_QM_PRICE = "quotemanager.price";
	public static final String CMD_QM_SAVE = "quotemanager.save";
	public static final String CMD_QM_COPY = "quotemanager.copy";
	public static final String CMD_QM_CREATENEWREVISION = "quotemanager.createnewrevision";
	public static final String CMD_QM_CREATESIGNATURE = "quotemanager.createsignature";
	public static final String CMD_QM_SIGNATURESTATUS = "quotemanager.signaturestatus";
	public static final String CMD_QM_NEXTREVUNS = "quotemanager.nextrevuns";
	public static final String CMD_QM_FETCHXLS = "quotemanager.fetchxls";
	public static final String CMD_QM_FETCHDOCX = "quotemanager.fetchdocx";
	public static final String CMD_QM_FETCHPDF = "quotemanager.fetchpdf";
	public static final String CMD_QM_FETCHSIGNATURE = "quotemanager.fetchsignature";
	public static final String CMD_QM_VOIDSIGNATURE = "quotemanager.voidsignature";
	public static final String CMD_QM_SUBMIT = "quotemanager.submit";
	public static final String CMD_QM_CONVERT = "quotemanager.convert";
	public static final String CMD_QM_PREVIEW = "quotemanager.preview";
	public static final String CMD_QM_REVOKE = "quotemanager.revoke";
	public static final String CMD_QM_CHANGESTATUS = "quotemanager.changestatus";
	public static final String CMD_QM_CREATION_WORKFLOW_SUBMIT = "quotemanager.creationworkflowsubmit";
	public static final String CMD_QM_CALCULATE_MASSUPDATE = "quotemanager.calculatemassupdate";
	public static final String CMD_QM_CANCEL_MASSUPDATE = "quotemanager.cancelmassupdate";
	public static final String CMD_QM_MASSUPDATE_COUNT_HEADERS = "quotemanager.massupdatecountheaders";

	public static final String CMD_METADATA_FETCH = "metadata.fetch";
	public static final String CMD_METADATA_FETCHSIGNIFICANTFIELDSONLY = "metadata.fetchsignificantfieldsonly";

	// Inline Details View Manager
	public static final String CMD_IDVM_FETCH = "inlinedetailsview.fetch";
	public static final String CMD_IDVM_FETCHCONFIGURATION = "inlinedetailsview.fetchConfiguration";

	// CLIC Manger
	public static final String CMD_CLICMGR_SENDEMAIL = "clicmanager.sendemail";
	public static final String CMD_CLICMGR_FORMATEMAILSUBJECT = "clicmanager.formatemailsubject";
	public static final String CMD_CLICMGR_FETCH = "clicmanager.fetch";
	public static final String CMD_CLICMGR_FETCHHEADER = "clicmanager.fetchheader";
	public static final String CMD_CLICMGR_FETCHHEADERTEXT = "clicmanager.fetchheadertext";
	public static final String CMD_CLICMGR_FETCH_OUTPUT = "clicmanager.fetchoutput";
	public static final String CMD_CLICMGR_FOLDER_STATS = "clicmanager.folderstats";
	public static final String CMD_CLICMGR_UPDATE = "clicmanager.update";
	public static final String CMD_CLICMGR_CALCULATE = "clicmanager.calculate";
	public static final String CMD_CLICMGR_CALCULATEDIRTY = "clicmanager.calculatedirty";
	public static final String CMD_CLICMGR_ADDFOLDER = "clicmanager.addfolder";
	public static final String CMD_CLICMGR_ADDITEMS = "clicmanager.additems";
	public static final String CMD_CLICMGR_DUPLICATEITEMS = "clicmanager.duplicateitems";
	public static final String CMD_CLICMGR_REMOVEITEMS = "clicmanager.removeitems";
	public static final String CMD_CLICMGR_RUNJOB = "clicmanager.runjob";
	public static final String CMD_CLICMGR_PREVIEW = "clicmanager.preview";
	public static final String CMD_CLICMGR_SUBMIT = "clicmanager.submit";
	public static final String CMD_CLICMGR_CANCEL = "clicmanager.cancel";
	public static final String CMD_CLICMGR_VALIDATE = "clicmanager.validate";
	public static final String CMD_CLICMGR_CREATION_WF_SUBMIT = "clicmanager.creationworkflowsubmit";
	public static final String CMD_CLICMGR_UPDATE_VIEW_STATE = "clicmanager.updateviewstate";

	// Promotion Manager
	public static final String CMD_CMGR_ADDITEMS = "contractmanager.additems";
	public static final String CMD_CMGR_FETCHITEMS = "contractmanager.fetchitems";
	public static final String CMD_CMGR_FETCH = "contractmanager.fetch";
	public static final String CMD_CMGR_CALCULATE = "contractmanager.calculate";
	public static final String CMD_CMGR_SAVE = "contractmanager.save";
	public static final String CMD_CMGR_COPY = "contractmanager.copy";
	public static final String CMD_CMGR_CREATENEWREVISION = "contractmanager.createnewrevision";
	public static final String CMD_CMGR_CREATESIGNATURE = "contractmanager.createsignature";
	public static final String CMD_CMGR_SIGNATURESTATUS = "contractmanager.signaturestatus";
	public static final String CMD_CMGR_NEXTREVUNS = "contractmanager.nextrevuns";
	public static final String CMD_CMGR_FETCHXLS = "contractmanager.fetchxls";
	public static final String CMD_CMGR_FETCHDOCX = "contractmanager.fetchdocx";
	public static final String CMD_CMGR_FETCHPDF = "contractmanager.fetchpdf";
	public static final String CMD_CMGR_FETCHSIGNATURE = "contractmanager.fetchsignature";
	public static final String CMD_CMGR_VOIDSIGNATURE = "contractmanager.voidsignature";
	public static final String CMD_CMGR_SUBMIT = "contractmanager.submit";
	public static final String CMD_CMGR_REVOKE = "contractmanager.revoke";
	public static final String CMD_CMGR_PREVIEW = "contractmanager.preview";
	public static final String CMD_CMGR_CREATION_WORKFLOW_SUBMIT = "contractmanager.creationworkflowsubmit";
	public static final String CMD_CMGR_CALCULATE_MASSUPDATE = "contractmanager.calculatemassupdate";
	public static final String CMD_CMGR_CANCEL_MASSUPDATE = "contractmanager.cancelmassupdate";
	public static final String CMD_CMGR_MASSUPDATE_COUNT_HEADERS = "contractmanager.massupdatecountheaders";

	// Rebate agreement manager
	public static final String CMD_RBA_ADDITEMS = "rebateagreement.additems";
	public static final String CMD_RBA_FETCHITEMS = "rebateagreement.fetchitems";
	public static final String CMD_RBA_FETCH = "rebateagreement.fetch";
	public static final String CMD_RBA_CALCULATE = "rebateagreement.calculate";
	public static final String CMD_RBA_SAVE = "rebateagreement.save";
	public static final String CMD_RBA_COPY = "rebateagreement.copy";
	public static final String CMD_RBA_CREATENEWREVISION = "rebateagreement.createnewrevision";
	public static final String CMD_RBA_CREATESIGNATURE = "rebateagreement.createsignature";
	public static final String CMD_RBA_SIGNATURESTATUS = "rebateagreement.signaturestatus";
	public static final String CMD_RBA_NEXTREVUNS = "rebateagreement.nextrevuns";
	public static final String CMD_RBA_FETCHXLS = "rebateagreement.fetchxls";
	public static final String CMD_RBA_FETCHDOCX = "rebateagreement.fetchdocx";
	public static final String CMD_RBA_FETCHPDF = "rebateagreement.fetchpdf";
	public static final String CMD_RBA_FETCHSIGNATURE = "rebateagreement.fetchsignature";
	public static final String CMD_RBA_VOIDSIGNATURE = "rebateagreement.voidsignature";
	public static final String CMD_RBA_SUBMIT = "rebateagreement.submit";
	public static final String CMD_RBA_REVOKE = "rebateagreement.revoke";
	public static final String CMD_RBA_PREVIEW = "rebateagreement.preview";
	public static final String CMD_RBA_CREATION_WORKFLOW_SUBMIT = "rebateagreement.creationworkflowsubmit";
	public static final String CMD_RR_CALCULATE = "rebaterecord.calculate";
	public static final String CMD_RR_SAVE = "rebaterecord.save";
	public static final String CMD_RR_CALCULATESET = "rebaterecord.calculateset";
	public static final String CMD_RR_CANCELSETCALC = "rebaterecord.cancelsetcalculation";
	public static final String CMD_RR_FETCH = "rebaterecord.fetch";
	public static final String CMD_RR_FETCHEXT = "rebaterecord.fetchext";
	public static final String CMD_RR_UPDATE = "rebaterecord.update";
	public static final String CMD_RR_COPY = "rebaterecord.copy";
	public static final String CMD_RR_SUBMIT = "rebaterecord.submit";
	public static final String CMD_RR_PREVIEW = "rebaterecord.preview";
	public static final String CMD_RR_APPROVE = "rebaterecord.approve";
	public static final String CMD_RR_REVOKE = "rebaterecord.revoke";
	public static final String CMD_RR_SAVECALC = "rebaterecord.savecalc";

	public static final String CMD_RAT_ADD = "rebateagreementtemplate.add";
	public static final String CMD_RAT_DELETE = "rebateagreementtemplate.delete";
	public static final String CMD_RAT_UPDATE = "rebateagreementtemplate.update";
	public static final String CMD_RAT_FETCH = "rebateagreementtemplate.fetch";
	public static final String CMD_RAT_EXECUTE = "rebateagreementtemplate.execute";
	public static final String CMD_RAT_COMPUTE_PARAMS = "rebateagreementtemplate.computeParams";
	public static final String CMD_RAT_SCHEDULE_TASK = "rebateagreementtemplate.scheduleTask";
	public static final String CMD_RAT_TASK_STATE = "rebateagreementtemplate.taskState";

	// claims
	public static final String CMD_CLM_FETCHITEMS = "claimmanager.fetchitems";
	public static final String CMD_CLM_UPDATEITEMS = "claimmanager.updateitems";
	public static final String CMD_CLM_CALCULATE = "claimmanager.calculate";
	public static final String CMD_CLM_CANCEL = "claimmanager.cancel";
	public static final String CMD_CLM_CLEARITEMS = "claimmanager.clearitems";
	public static final String CMD_CLM_FETCHITEMALERTS = "claimmanager.fetchitemalerts";
	public static final String CMD_CLM_VALIDATEITEMS = "claimmanager.validateitems";
	public static final String CMD_CLM_REJECTITEMS = "claimmanager.rejectitems";
	public static final String CMD_CLM_SUMMARY = "claimmanager.summary";
	public static final String CMD_CLM_SUBMIT = "claimmanager.submit";
	public static final String CMD_CLM_PREVIEW = "claimmanager.preview";
	public static final String CMD_CLM_REVOKE = "claimmanager.revoke";
    public static final String CMD_CLM_FETCH_ALLOCATION_GRID = "claimmanager.fetchallocationgrid";

	// deal planner
	public static final String CMD_DPM_FETCH = "dealplanmanager.fetch";
	public static final String CMD_DPM_FETCHRESULTS = "dealplanmanager.fetchresults";
	public static final String CMD_DPM_SAVE = "dealplanmanager.save";
	public static final String CMD_DPM_ADD = "dealplanmanager.add";
	public static final String CMD_DPM_DELETE = "dealplanmanager.delete";
	public static final String CMD_DPM_UPDATE = "dealplanmanager.update";
	public static final String CMD_DPM_SUBMIT = "dealplanmanager.submit";
	public static final String CMD_DPM_PREVIEW = "dealplanmanager.preview";
	public static final String CMD_DPM_CHANGESTATUS = "dealplanmanager.changestatus";
	public static final String CMD_DPM_DUPLICATE = "dealplanmanager.duplicate";

	// Models (PO)
	public static final String CMD_MR_CALCULATE = "modelrecord.calculate";
    public static final String CMD_MR_SAVE = "modelrecord.save";
    public static final String CMD_MR_FETCH = "modelrecord.fetch";
    public static final String CMD_MR_FETCHEXT = "modelrecord.fetchext";
    public static final String CMD_MR_UPDATE = "modelrecord.update";
    public static final String CMD_MR_COPY = "modelrecord.copy";
    public static final String CMD_MR_DELETE = "modelrecord.delete";
    public static final String CMD_MR_SUBMIT = "modelrecord.submit";
    public static final String CMD_MR_MASSSUBMIT = "modelrecord.masssubmit";
    public static final String CMD_MR_PREVIEW = "modelrecord.preview";
    public static final String CMD_MR_APPROVE = "modelrecord.approve";
    public static final String CMD_MR_REVOKE = "modelrecord.revoke";

    public static final String CONFIGURATOR_PREFIX_MODELEVAL = "model:";
    public static final String CONFIGURATOR_PREFIX_CONFWIZARD = "configurationWizard:";
	public static final String CONFIGURATOR_PREFIX_CONFWIZARD_EXECUTION = "configurationWizardExecution:";

    // Scenarios
    public static final String CMD_SCN_FETCH = "scenario.fetch";
    public static final String CMD_SCN_PARAMS = "scenario.params";

	public static final String CMD_KV_PARAM_TTL = "ttl";
	public static final String CMD_KV_PARAM_KEYS = "keys";
	public static final String CMD_KV_PARAMS_PAYLOAD = "payload";

	public static final String CMD_USERHELP_FETCH = "userhelp.fetch";
	public static final String CMD_USERHELP_GET = "userhelp.get";

	public static final String CMD_CLIENTLOGGER_LOG = "clientlogger.log";

	public static final String CMD_EMAIL_RESEND = "email.resend";
	public static final String CMD_ETM_TESTEXEC = "emailtemplatemanager.testexec";

	public static final String CMD_ENTITYEDITORLOG_PING = "entityeditorlog.ping";
	public static final String CMD_ENTITYEDITORLOG_DELETE = "entityeditorlog.delete";

	// Product manager
	public static final String CMD_PRODM_FETCH = "productmanager.fetch";
	public static final String CMD_PRODM_FETCHPRODUCTS = "productmanager.fetchproducts";
	public static final String CMD_PRODM_FETCHFORMULAFILTEREDPRODUCTS = "productmanager.fetchformulafilteredproducts";
	public static final String CMD_PRODM_FETCHPRODUCTXREF = "productmanager.fetchproductxref";
	public static final String CMD_PRODM_FETCHPRODUCTCOMPETITION = "productmanager.fetchproductcompetition";
	public static final String CMD_PRODM_FETCHPRODUCTBOM = "productmanager.fetchproductbom";
	public static final String CMD_PRODM_QUICKSEARCH = "productmanager.quicksearch";

	public static final String CMD_FETCHPRODUCTSET_COMPETITION = "productmanager.fetchproductsetcompetition";
	public static final String CMD_PRODM_IMPORTPRODUCTCOMPETITION = "productmanager.importproductcompetition";


	// Product manager BOM related
	public static final String CMD_PRODM_DELETEBOM = "productmanager.deletebom";
	public static final String CMD_PRODM_ADDBOM = "productmanager.addbom";
	public static final String CMD_PRODM_COPYBOM = "productmanager.copybom";
	public static final String CMD_PRODM_UPDATEBOM = "productmanager.updatebom";
	public static final String CMD_PRODM_ROLLUPBOM = "productmanager.rollupbom";
	public static final String CMD_PRODM_BOMTREE = "productmanager.bomtree";
	public static final String CMD_PRODM_BOMREFERENCES = "productmanager.bomreferences";
	public static final String CMD_PRODM_FETCHPXAM = "productmanager.fetchpxam";

	// Customer Manager
	public static final String CMD_CUSTM_FETCH = "customermanager.fetch";
	public static final String CMD_CUSTM_FETCHCUSTOMERS = "customermanager.fetchcustomers";
	public static final String CMD_CUSTM_FETCHFORMULAFILTEREDCUSTOMERS = "customermanager.fetchformulafilteredcustomers";
	public static final String CMD_CUSTM_ASSIGN = "customermanager.assign";
	public static final String CMD_CUSTM_FETCHASSIGNMENTS = "customermanager.fetchassignments";
	public static final String CMD_CUSTM_FETCHCXAM = "customermanager.fetchcxam";

	public static final String CMD_FILTERNODE_REPARENT = "filternode.reparent";

	// datamart
	public static final String CMD_DM_GETCONFIG = "datamart.getconfig";

	public static final String CMD_DM_NEWFC = "datamart.newfc";
	public static final String CMD_DM_COPYFC = "datamart.copyfc";
	public static final String CMD_DM_GETFCS = "datamart.getfcs";
	public static final String CMD_DM_UPDATEFC = "datamart.updatefc";
	public static final String CMD_DM_DELETEFC = "datamart.deletefc";
	public static final String CMD_DM_VALIDATEFC = "datamart.validatefc";
	public static final String CMD_DM_MERGEFC = "datamart.mergefc";
	public static final String CMD_DM_IMPORTFC = "datamart.importfc";		// creates or updates FC - no version check on update
	public static final String CMD_DM_RESTOREDEFAULTDS = "datamart.restoredefaultds";

	public static final String CMD_DM_ADDENTITLEMENTS = "datamart.addentitlements";
	public static final String CMD_DM_FETCHENTITLEMENTS = "datamart.fetchentitlements";
	public static final String CMD_DM_UPDATEENTITLEMENTS = "datamart.updateentitlements";
	public static final String CMD_DM_DELETEENTITLEMENTS = "datamart.deleteentitlements";

	public static final String CMD_DM_QUERY = "datamart.query";
	public static final String CMD_DM_FETCHQUERYEXCEL = "datamart.fetchqueryexcel";

	public static final String CMD_DM_GETDATASOURCE = "datamart.getdatasource";	// for backwards compatibility with 2.8 ((preferred method is now datamart.getfc)
	public static final String CMD_DM_GETDATAMART = "datamart.getdatamart";		// for backwards compatibility with 2.8 ((preferred method is now datamart.getfc)
	public static final String CMD_DM_GETDATACHUNK = "datamart.getdatachunk";

	public static final String CMD_DM_FETCH = "datamart.fetch";					// sgwt like CRUD command
	public static final String CMD_DM_FETCHNOCOUNT = "datamart.fetchnocount";	// for integration use, not issuing the expensive count() that determines #total rows
	public static final String CMD_DM_ADD = "datamart.add";						// sgwt like CRUD command
	public static final String CMD_DM_UPDATE = "datamart.update";				// sgwt like CRUD command
	public static final String CMD_DM_DELETE = "datamart.delete";				// sgwt like CRUD command
	public static final String CMD_DM_MASSEDIT = "datamart.massedit";

	public static final String CMD_DM_STATUS = "datamart.status";
	public static final String CMD_DM_CANCELACTION = "datamart.cancelaction";
	public static final String CMD_DM_LOADDATA = "datamart.loaddata";
	public static final String CMD_DM_IMPORTFILE = "datamart.importfile";
	public static final String CMD_DM_EXPORTDATA = "datamart.exportdata";
	public static final String CMD_DM_RELOAD = "datamart.reload";			// for backwards compatibility with 2.7 (preferred method is now datamart.rundataload)
	public static final String CMD_DM_REFRESH = "datamart.refresh";			// for backwards compatibility with 2.6

	public static final String CMD_DM_GETDATALOADS = "datamart.getdataloads";
	public static final String CMD_DM_UPDATEDATALOAD = "datamart.updatedataload";
	public static final String CMD_DM_RUNDATALOAD = "datamart.rundataload";
	public static final String CMD_DM_CANCELDATALOAD = "datamart.canceldataload";
	public static final String CMD_DM_IMPORTDATALOADS = "datamart.importdataloads";
	public static final String CMD_DM_TESTCALCULATION = "datamart.testcalculation";

	public static final String CMD_DM_FORMULAPARAMS = "datamart.formulaparams";
	public static final String CMD_DM_DISTCALCPARAMS = "datamart.distcalcparams";
	public static final String CMD_DM_DISTCALCEXEC = "datamart.distcalcexec";
	public static final String CMD_DM_MODELEVAL = "datamart.modeleval";
	public static final String CMD_DM_REPARENTMODEL = "datamart.reparentmodel";
	public static final String CMD_DM_EVALUATE = "datamart.evaluate";
	public static final String CMD_DM_GETCHARTS = "datamart.getcharts";
	public static final String CMD_DM_GETROLLUPS = "datamart.getrollups";
	public static final String CMD_DM_ACTIONSTATUS = "datamart.getactionstatus";
	public static final String CMD_DM_UTIL = "datamart.util";
	public static final String SUBCMD_DM_UTIL_DATA2DS = "data2ds";
	public static final String SUBCMD_DM_UTIL_DATA2DF = "data2df";
	public static final String SUBCMD_DM_UTIL_DF2DSFORMULA = "df2dsformula";
	public static final String SUBCMD_DM_UTIL_FORMULA2FC = "formula2fc";
	public static final String SUBCMD_DM_UTIL_PURGECACHE = "purgecache";
	public static final String SUBCMD_DM_UTIL_QUERY2FC = "query2fc";

	public static final String CMD_DM_SYS_EXPORT = "system$datamartexport";
	public static final String CMD_DM_SYS_IMPORT = "system$datamartimport";
	public static final String CMD_DM_EXPORT = "datamart.export";
	public static final String CMD_DM_IMPORT = "datamart.import";
	public static final String CMD_DM_STAGEIMPORTFILE = "datamart.stageimportfile";
	public static final String CMD_DM_FETCHEXPORTFILE = "datamart.fetchexportfile";

	// download manager
	public static final String CMD_DLM_DOWNLOAD = "downloadmanager.download";

	// async download (node bound) manager
	public static final String CMD_ADLM_ISREADY = "asyncdownloadmanager.isready";
	public static final String CMD_ADLM_DOWNLOAD = "asyncdownloadmanager.download";
	public static final String CMD_ADLM_CANCEL = "asyncdownloadmanager.cancel";

	// upload manager
	public static final String CMD_ULM_NEWUPLOADSLOT = "uploadmanager.newuploadslot";
	public static final String CMD_ULM_PROGRESS = "uploadmanager.progress";
	public static final String CMD_ULM_UPLOADCANCEL = "uploadmanager.uploadcancel";
	public static final String CMD_ULM_DELETESLOT = "uploadmanager.deleteslot";

	// binary data manager
	public static final String CMD_BDM_UPLOAD = "bdmanager.upload";
	public static final String CMD_BDM_LIST = "bdmanager.list";
	public static final String CMD_BDM_DOWNLOAD = "bdmanager.download";
	public static final String CMD_BDM_DELETE = "bdmanager.delete";
	public static final String CMD_BDM_UPDATE = "bdmanager.update";
	public static final String CMD_BDM_EDIT = "bdmanager.edit";
	public static final String CMD_BDM_FETCH_FROM_UPLOADSLOT = "bdmanager.fetchfromuploadslot";
	public static final String CMD_BDM_CHECK_IF_EXISTS = "bdmanager.checkifexists";

	// document data manager
	public static final String CMD_DDM_ADD = "ddmanager.add";
	public static final String CMD_DDM_UPDATE = "ddmanager.update";
	public static final String CMD_DDM_DELETE = "ddmanager.delete";
	public static final String CMD_DDM_FETCH = "ddmanager.fetch";
	public static final String CMD_DDM_FETCHRELATED = "ddmanager.fetchrelated";

	// cloudconvert manager
	public static final String CMD_FILECONVERSIONMANAGER_USER = "fileconversionmanager.user";

	// configuration manager
	public static final String CMD_CONFM_SET = "configurationmanager.set";
	public static final String CMD_CONFM_GET = "configurationmanager.get";
	public static final String CMD_CONFM_GETMULTIPLE = "configurationmanager.getMultiple";
	public static final String CMD_CONFM_GETGLOBALEXT = "configurationmanager.getglobalextensions";
	public static final String CMD_CONFM_DELETE = "configurationmanager.delete";
	public static final String CMD_CONFM_GETDEFAULT = "configurationmanager.getdefault";

	public static final String CMD_REMOTE_INTEGRATION_TEST_MANAGER = "remoteintegrationtestmanager";

	@Deprecated
	public static final String CMD_CONFM_CHECKTEMPLATEPRESENT = "configurationmanager.checktemplatepresent";
	@Deprecated
	public static final String CMD_CONFM_TEMPLATEPRESENTLIST = "configurationmanager.templatepresentlist";
	public static final String CMD_CONFM_ALLTEMPLATESPRESENTLISTS = "configurationmanager.alltemplatespresentlists";
	public static final String CMD_CONFM_UPLOADTEMPLATE = "configurationmanager.uploadtemplate";
	public static final String CMD_CONFM_FETCHTEMPLATES = "configurationmanager.fetchtemplates";
	public static final String CMD_CONFM_SAVETEMPLATES = "configurationmanager.savetemplates";
	public static final String CMD_CONFM_DELETETEMPLATE = "configurationmanager.deletetemplate";
	public static final String CMD_CONFM_GETTEMPLATEDOWNLOADURL = "configurationmanager.gettemplatedownloadurl";
	public static final String CMD_CONFM_FETCHPLASMA = "configurationmanager.fetchplasma";
	public static final String CMD_CONFM_SAVEPLASMA = "configurationmanager.saveplasma";
	public static final String CMD_CONFM_FETCHTIMEZONES = "configurationmanager.fetchtimezones";
	public static final String CMD_CONFM_FETCHMESSAGETEMPLATES = "configurationmanager.fetchmessagetemplates";
	public static final String CMD_CONFM_SAVEMESSAGETEMPLATE = "configurationmanager.savemessagetemplate";
	public static final String CMD_CONFM_FETCH_AVAILABLE_HOOKS = "configurationmanager.fetchavailablehooks";


	public static final String CMD_CONFM_MOVEOX = "configurationmanager.moveox";

	public static final String CMD_HELPM_UPDATE = "helpmanager.update";
	public static final String CMD_HELPM_FETCH = "helpmanager.fetch";


	// messages
	public static final String CMD_MESSAGES_FETCH = "messages.fetch";
	public static final String CMD_MESSAGES_FETCHUSERS = "messages.fetchusers";
	public static final String CMD_MESSAGES_ADD = "messages.add";
	public static final String CMD_MESSAGES_REPLY = "messages.reply";

	// product images
	public static final String CMD_PRODUCTIMAGES_UPLOAD = "productimages.upload";
	public static final String CMD_PRODUCTIMAGES_GET = "productimages.get";
	public static final String CMD_PRODUCTIMAGES_CONTAINS_IMAGE = "productimages.containsImage";
	public static final String CMD_PRODUCTIMAGES_DELETE_IMAGE = "productimages.deleteImage";

	// recommendations
	public static final String CMD_RECOMMENDATIONS_RECOMMEND = "recommendations.recommend";

	// in app feedback
	public static final String CMD_IN_APP_FEEDBACK_CREATE = "inappfeedback.create";
	public static final String CMD_IN_APP_FEEDBACK_ADD_ATTACHMENT = "inappfeedback.attachment.add";


	// do not forget to reflect any changes made here in ConfigurationManagerServiceImpl.getAllSettingNames()
	public static final String SETTINGNAME_ALLOWED_LENGTH_OF_GROUPS_SELECTION_FOR_OX = "allowedLengthOfGroupsSelectionForOX";
	public static final String SETTINGNAME_BASEURL = "baseUrl";
	public static final String SETTINGNAME_UNITYLINKENABLED = "unityLinkEnabled";
	public static final String SETTINGNAME_UNITYDIALOGENABLED = "unityDialogEnabled";
	public static final String SETTINGNAME_UNITYDIALOG = "unityDialog";
	public static final String SETTINGNAME_WATERFALLTEMPLATE = "waterfalltemplate";
	public static final String SETTINGNAME_PRODUCTEXTENSION = "productextension";
	public static final String SETTINGNAME_CUSTOMEREXTENSION = "customerextension";
	public static final String SETTINGNAME_PRODUCTQUERIES = "productqueries";
	public static final String SETTINGNAME_PRODUCTQUERYCHARTS = "productQueryCharts";
	public static final String SETTINGNAME_CUSTOMERQUERIES = "customerqueries";
	public static final String SETTINGNAME_CUSTOMERQUERYCHARTS = "customerQueryCharts";
	public static final String SETTINGNAME_REBATECHARTS = "rebateCharts";
	public static final String SETTINGNAME_REBATEQUERIES = "rebateQueries";
	public static final String SETTINGNAME_PA_AUTOLOADDATA = "paAutoLoadData";
	public static final String SETTINGNAME_PA_DAILYCCYRATES = "paDailyCurrencyConversionRates";
	public static final String SETTINGNAME_PA_DMFILTER_DROPDOWN_USES_DS = "paDMFilterDropdownUsesUnderlyingDS";
	public static final String SETTINGNAME_PA_DM_NO_GROUP_ALL_ACCESS = "paDmNoGroupAllAccess";
	public static final String SETTINGNAME_PATOPBMAPPING_SKU = "paToPbMappingSKU";
	public static final String SETTINGNAME_PATOPBMAPPING_CUSTOMER_ID = "paToPbMappingCustomerId";
	public static final String SETTINGNAME_MESSAGE_TEMPLATE_PREFIX = "msgTemplate";
	public static final String SETTINGNAME_MESSAGE_TEMPLATE_LANGS = "languagesForMsgTemplates";
	public static final String SETTINGNAME_FLEXCHART_TEMPLATES = "flexChartTemplates";
	public static final String SETTINGNAME_DEFAULTTIMEZONE = "defaultTimezone"; // @Deprecated and to be removed in 5.0
	public static final String SETTINGNAME_DEFAULTTIMEZONEID = "defaultTimezoneId";
	public static final String SETTINGNAME_EMAILREDIRECT = "emailRedirect";
	public static final String SETTINGNAME_PWDCOMPLEXITYRULES = "pwdComplexityRules";
	public static final String SETTINGNAME_GRIDMAXGROUPBYITEMS = "gridMaxGroupByItems";
	public static final String SETTINGNAME_AUTOCONVERTQUOTES = "autoConvertQuotes";
	public static final String SETTINGNAME_CHARTUSEUTC = "chartUseUTC";
	public static final String SETTINGNAME_CHARTEMBEDDEDBOXPLOTSERIESCOLOR = "chartEmbeddedBoxplotSeriesColor";
	public static final String SETTINGNAME_CHARTSERIESCOLORS = "chartSeriesColors";
	public static final String SETTINGNAME_CHARTWATERFALLSERIESCOLORS = "chartWaterfallSeriesColors";
	public static final String SETTINGNAME_CHARTHEATMAPCOLORS = "chartHeatmapColors";
	public static final String SETTINGNAME_CHARTBANDBYCOLORS = "chartBandByColors";
	public static final String SETTINGNAME_CHART_HIGHCHARTSTHEME = "chartHighchartsTheme";
	public static final String SETTINGNAME_QUOTEEXPIRYDATEOFFSET = "quoteExpiryDateOffset";
	public static final String SETTINGNAME_QUOTETARGETDATEOFFSET = "quoteTargetDateOffset";
	public static final String SETTINGNAME_COMMENTHISTORY = "commentHistory";
	public static final String SETTINGNAME_TEXTMATCHSTYLE = "defaultTextMatchStyle";
	public static final String SETTINGNAME_PRICEGRID_EVENTBEFORERESHIFT = "priceGrid.eventBeforeRecalc"; //used to be recalc
	public static final String SETTINGNAME_STARTPAGEPANELS = "startPagePanels";
	public static final String SETTINGNAME_DEFAULTGROUPS = "defaultGroups";
	public static final String SETTINGNAME_HIDDENPDEWIDGETS = "hiddenPDEWidgets";
	public static final String SETTINGNAME_ALLOW_SANDBOX_LOGGING = "allowSandboxLogging";
	public static final String SETTINGNAME_PASSWORDHISTORY_ENABLED = "passwordHistoryActive";
	public static final String SETTINGNAME_PWNDEDPASSWORDCHECK_ENABLED = "pwnedPasswordCheck";
	public static final String SETTINGNAME_PASSWORDHISTORY_COUNT = "passwordHistoryCount";
	public static final String SETTINGNAME_PASSWORDEXPIRY_DAYS = "passwordExpiryDays";
	public static final String SETTINGNAME_AVAILABLE_WORKSTATUS = "availableWorkStatus";
	public static final String SETTINGNAME_PGI_DENIALREASONS = "pgiDenialReasons";
	public static final String SETTINGNAME_PGI_AUTODELETEOFSUBMITTEDITEMS = "allowAutoDeletionOfSubmittedPGI";
	public static final String SETTINGNAME_SHOTGUN_THRESHOLD = "shotgunThreshold";
	public static final String SETTINGNAME_REFRESH_PDELIST_ON_UPDATE = "refreshPDEListOnUpdate";
	public static final String SETTINGNAME_SAML_CONFIGURATION = "samlConfiguration";
	public static final String SETTINGNAME_EXTRANAV_HTML = "extraNavigationHtml";
	public static final String SETTINGNAME_CONFIGURATOR_SHOWPROGRESS = "configuratorShowProgress";
	public static final String SETTINGNAME_INFER_MASSEDIT_ROUNDING = "inferMassEditRounding";
	public static final String SETTINGNAME_QUOTE_ADDCUSTOMERINPUT = "quoteAddCustomerInput";
	public static final String SETTINGNAME_QUOTE_ADDCUSTOMERGROUPINPUT = "quoteAddCustomerGroupInput";
	public static final String SETTINGNAME_QUOTE_CALCNEWIMMEDIATELY = "calculateNewQuoteImmediately";
	public static final String SETTINGNAME_QUOTE_SAVEANDCALCNEWIMMEDIATELY = "saveAndCalculateNewQuoteImmediately";
	public static final String SETTINGNAME_QUOTE_APPLYCUSTOMERFILTER = "quoteApplyCustomerFilter";
	public static final String SETTINGNAME_QUOTE_APPLYOWNQUOTESFILTER = "quoteApplyOwnQuotesFilter";
	public static final String SETTINGNAME_QUOTE_ALLOW_CONVERSION_OF_EXPIRED = "allowConversionOfExpired";
	public static final String SETTINGNAME_RBA_CALCNEWIMMEDIATELY = "calculateNewRBAImmediately";
	public static final String SETTINGNAME_RBA_SAVEANDCALCNEWIMMEDIATELY = "saveAndCalculateNewRBAImmediately";
	public static final String SETTINGNAME_CONTRACT_CALCNEWIMMEDIATELY = "calculateNewContractImmediately";
	public static final String SETTINGNAME_CONTRACT_SAVEANDCALCNEWIMMEDIATELY = "saveAndCalculateNewContractImmediately";
	public static final String SETTINGNAME_CLAIM_CREATE_FROM_QUOTE_LOGIC = "claimCreateFromQuoteLogic";
	public static final String SETTINGNAME_CLAIM_CREATE_FROM_CONTRACT_LOGIC = "claimCreateFromContractLogic";
	public static final String SETTINGNAME_DEFAULTPLFORMULA = "defaultPLFormula";
	public static final String SETTINGNAME_DEFAULTPGFORMULA = "defaultPGFormula";
	public static final String SETTINGNAME_DEFAULTPL_USERNOTIFICATION = "defaultPLUserNotification";
	public static final String SETTINGNAME_DEFAULTPL_PREFINFO = "defaultPLPreferenceInfo";
	public static final String SETTINGNAME_CLOUDCONVERT = "cloudConvertToken";
	public static final String SETTINGNAME_CLOUDCONVERT_SECRET_KEY = "cloudconvert_secretkey";
	public static final String SETTINGNAME_CLOUDCONVERTUSAGEAGREED  = "cloudConvertTokenUsageAgreed";
	public static final String SETTINGNAME_CUSTOM_SMTP  = "customSMTP";
	public static final String SETTINGNAME_SKIP_REVISIONRECALC_PREFIX  = "skipRevisionRecalc_";
	public static final String SETTINGNAME_CLIC_WF_BYTARGETDATE = "clicWorkflowByTargetDate";
	public static final String SETTINGNAME_ALWAYS_SHOW_MYPENDINGAPPROVALS = "alwaysShowMyPendingApprovals";
	public static final String SETTINGNAME_ALWAYS_SHOW_MYPENDINGCREATIONWORKFLOWS = "alwaysShowMyPendingCreationWorkflows";
	public static final String SETTINGNAME_ALWAYS_SHOW_MYTODOS = "alwaysShowMyToDos";
	public static final String SETTINGNAME_DISABLED_WF_TEMPLATES = "wfDisabledTemplates";
	public static final String SETTINGNAME_DISABLED_AUTOLOGIN = "disabledAutoLogin";
	public static final String SETTINGNAME_EVENTURL = "eventUrl";
	public static final String SETTINGNAME_DISABLED_EVENTPROCESSING = "disabledEventProcessing";
	public static final String SETTINGNAME_EVENTEMAIL = "eventEmail";
	public static final String SETTINGNAME_DISABLED_EMAILPROCESSING = "disabledEmailProcessing";
	public static final String SETTINGNAME_OBJREFAFTERSAVEDISABLED = "objRefAfterSaveDisabled";
	public static final String SETTINGNAME_UPDATE_HEADERREF_IN_SYNC_AFTER_SAVE_DISABLED = "updateHeaderRefInSyncAfterSaveDisabled";
	public static final String SETTINGNAME_TFA_MANDATORY = "tfaMandatory";
	public static final String SETTINGNAME_EXTERNALJWTCONFIG = "externalJWTConfiguration";
	public static final String SETTINGNAME_DISABLE_ATTACHING_ATTACHMENTS_ON_SUBMIT = "disableAttachingAttachmentsOnSubmit";
	public static final String SETTINGNAME_ENABLE_CREATION_WORKFLOW_FOR_TYPES = "enableCreationWorkflowForTypes";
	public static final String SETTINGNAME_ENABLE_SUBMIT_REASON_FOR_TYPES = "enableSubmitReasonForTypes";
	public static final String SETTINGNAME_DISABLE_SAVE_WHEN_CREATION_WORKFLOW_IS_FINISHED_QUOTE = "disableSaveWhenCreationWorkflowIsFinishedQuote";
	public static final String SETTINGNAME_DISABLE_SAVE_WHEN_CREATION_WORKFLOW_IS_FINISHED_CONTRACT = "disableSaveWhenCreationWorkflowIsFinishedContract";
	public static final String SETTINGNAME_DISABLE_SAVE_WHEN_CREATION_WORKFLOW_IS_FINISHED_RBA = "disableSaveWhenCreationWorkflowIsFinishedRBA";
	public static final String SETTINGNAME_RUN_CREATION_WORKFLOW_ON_QUOTE_SAVE = "runCreationWorkflowOnQuoteSave";
	public static final String SETTINGNAME_RUN_CREATION_WORKFLOW_ON_CONTRACT_SAVE = "runCreationWorkflowOnContractSave";
	public static final String SETTINGNAME_RUN_CREATION_WORKFLOW_ON_REBATEAGREEMENT_SAVE = "runCreationWorkflowOnRebateAgreementSave";
	public static final String SETTINGNAME_MANDATORY_PL_ELEMENTS = "mandatoryPLElements";
	public static final String SETTINGNAME_PRICELIST_LOGICS = "pricelistLogics";
	public static final String SETTINGNAME_QUOTE_ITEM_SELECTOR_INPUTS = "quoteItemSelectorInputs";
	public static final String SETTINGNAME_LOADDATA_SYNC_ON_TARGET_TABLE = "loadDataSyncOnTargetTable";
	public static final String SETTINGNAME_MARIADB_VIRTUAL_COLUMNS_MAPPING = "mariadbVirtualColumnsMapping"; // a json with mapping from JSON_VALUE
	public static final String SETTINGNAME_AUTOGENERATE_KEYS_IN_PP = "autogenerateKeysInPP";
	public static final String SETTINGNAME_DECOUPLE_OX = "decoupleOX";
	public static final String SETTINGNAME_USE_BINARYDATA_GROUP_RESTRICTION = "useBinaryDataGroupRestriction";
	public static final String SETTINGNAME_QUOTE_MASS_UPDATE_TEMPLATES = "quotesMassUpdateTemplates";
	public static final String SETTINGNAME_CONTRACT_MASS_UPDATE_TEMPLATES = "contractsMassUpdateTemplates";
	public static final String SETTINGNAME_AUTOGROUP_CALCULATIONRESULTS = "autoGroupCalculationResultsInDetailsView";
	public static final String SETTINGNAME_CO_PREFERREDMAPPING = "calculableObjectPreferredMapping";
	public static final String SETTINGNAME_DISABLED_DOCXDOWNLOAD = "disabledDocxDownload";
	public static final String SETTINGNAME_HIDE_PP_TABLES_BASED_ON_USERGROUPS = "hidePPTablesBasedOnUserGroups";
    public static final String SETTINGNAME_DATASOURCE_OPTIONS_FETCH_LIMIT = "datasourceOptionsFetchLimit";
    public static final String SETTINGNAME_ESIGNATURE = "ESignature";
	public static final String SETTINGNAME_ESIGNATURE_AVAILABLE = "ESignatureAvailable";
	public static final String SETTINGNAME_ESIGNATURE_SANDBOX = "ESignatureUseSandbox";
	public static final String SETTINGNAME_EXTRA_EXPORT_COLUMNS_CONFIG = "extraExportColumnsConfig";
	public static final String SETTINGNAME_PAYOUTRECORDSCONFIG = "payoutRecordsConfiguration";
	public static final String SETTINGNAME_AVANCED_DELETE_CONFIRMATION_DIALOG_THRESHOLD = "advancedDeleteConfirmationDialogThreshold";
	public static final String SETTINGNAME_GRID_EXPORT_USER_GROUPS = "gridExportUserGroups";
	public static final String SETTINGNAME_ENABLE_GRID_EXPORT_ONLY_FOR_DEFINED_USER_GROUPS = "enableGridExportOnlyForDefinedUserGroups";
	public static final String SETTINGNAME_ADVANCED_FILTER_COMBOBOX_DISABLE_AUTOSUGGEST = "advancedFilterComboboxDisableAutosuggest";
	public static final String SETTINGNAME_FORMULAENGINE_RETAINGLOBAL_ALWAYSON = "retainGlobalAlwaysOn";
	public static final String SETTINGNAME_PRICELIST_TARGETDATE_EDITABLE = "pricelistTargetDateEditable";
	public static final String SETTINGNAME_QUOTE_PRODUCT_RECOMMENDATIONS_CONFIG = "quoteProductRecommendationsConfig";
	public static final String SETTINGNAME_DISABLE_O365_LOGIN = "disableO365Login";
	public static final String SETTINGNAME_PP_DEFAULT_KEY_VALUE = "PPDefaultKeyValue";
	public static final String SETTINGNAME_WF_SUMMARY_EMAIL_FREQUENCY = "wfSummaryEmailFrequency";
	public static final String SETTINGNAME_WF_SUMMARY_EMAIL_DAILY = "wfSummaryEmailDaily";
	public static final String SETTINGNAME_RERENDER_INPUTS_ONFETCH = "rerenderInputsOnFetch";
	public static final String SETTINGNAME_EVENT_HOOKS_CONFIG = "eventHooksConfig";
	public static final String SETTINGNAME_DISABLEREDISLOGS = "disableRedisLogs";
	public static final String SETTINGNAME_DO_NOT_STORE_GLOBALS_FOR_DIRTYPASS = "doNotStoreGlobalsForDirtyPass";
	public static final String SETTINGNAME_COPY_LASTUPDATEDATE_ON_FLUSH = "copyLastUpdateDateOnFLush";
	public static final String SETTINGNAME_QUOTE_REVISION_FORMAT = "quoteRevisionFormat";
	public static final String SETTINGNAME_CONTRACT_REVISION_FORMAT = "contractRevisionFormat";
	public static final String SETTINGNAME_REBATE_REVISION_FORMAT = "rebateRevisionFormat";
	public static final String SETTINGNAME_TRUNCATE_DM_ON_NONINC_REFRESH = "truncateDatamartOnNonIncRefresh";
	public static final String SETTINGNAME_DISABLE_PASSWORD_EXPIRATION_EMAIL_NOTIFICATIONS = "disablePasswordExpirationEmailNotifications";
	public static final String SETTINGNAME_DAYS_BEFORE_SENDING_PASSWORD_EXPIRATION_EMAIL_NOTIFICATION = "daysBeforeSendingPasswordExpirationEmailNotification";
	public static final String SETTINGNAME_PA_SHOW_HIDDEN_FIELDS_IN_DATA_GRID = "paShowHiddenFieldsInDataGrid";

	/** i18n manager */
	public static final String CMD_I18NM_FETCH = "i18nmanager.fetch";
	public static final String CMD_I18NM_EDITINGFETCH = "i18nmanager.editingfetch";
	public static final String CMD_I18NM_SAVE = "i18nmanager.save";
	public static final String CMD_I18NM_DELETE = "i18nmanager.delete";
	public static final String CMD_I18NM_FETCHXLS = "i18nmanager.fetchXls";
	public static final String CMD_I18NM_IMPORTXLS = "i18nmanager.importXls";

	/**
	 *
	 * PARAMETERS
	 *
	 */
	// generic
	public static final String PARAM_TYPEDID = "typedId";
	public static final String PARAM_TYPEDIDS = "typedIds";
	public static final String PARAM_UNIQUENAME = "uniqueName";
    public static final String PARAM_FIELD = "field";
	public static final String PARAM_TARGETDATE = "targetDate";
	public static final String PARAM_FORMULANAME = "formulaName";
	public static final String PARAM_SORTBY = "sortBy";
	public static final String PARAM_DISTINCTRESULTS = "distinctResults";
	public static final String PARAM_VALUEFIELDS = "valueFields"; // this will return an Object[]
	public static final String PARAM_RESULTFIELDS = "resultFields"; // this will filter the JSON Object fields
	public static final String PARAM_RESULTFIELDTITLES = "resultFieldTitles"; // this is an optional label for the resultFields
	public static final String PARAM_JOINFIELDS = "joinFields"; // used in loaddata to specify the "key"
	public static final String PARAM_MAXJOINFIELDSLENGTHS = "maxJoinFieldsLengths";
	public static final String PARAM_DETECTJOINFIELDS = "detectJoinFields"; // enables joinFields autodetection on PX/CX
	public static final String PARAM_SYNC_ON_TARGET_TABLE = "syncOnTargetTable"; // loaddata, if set, app will try to gather distributed lock before execute
	public static final String PARAM_FORMULAPARAMS = "formulaParams";
	public static final String PARAM_DELETE = "delete";
	public static final String PARAM_UNDELETE = "undelete";
	public static final String PARAM_REPLACE = "replace";
	public static final String PARAM_SKUS = "skus";
	public static final String PARAM_URL = "url";
	public static final String PARAM_CHARTSVG_B64ZLIB = "chartSVG_B64ZLIB";
	public static final String PARAM_CHART_BUILDEREXPR_B64 = "chartBuilderExpr_B64";
	public static final String PARAM_TEMPLATE_NAME = "templateName";
	public static final String PARAM_USERS = "users";
	public static final String PARAM_MAXROWS = "maxRows";
	public static final String PARAM_SUFFIX = "suffix";
	public static final String PARAM_FILENAME = "fileName";
	public static final String PARAM_TRUNCATE = "truncate";
	public static final String PARAM_DEDUPLICATE = "deDuplicate";
	public static final String PARAM_SANITIZE = "sanitize";
	public static final String PARAM_INCREMENTAL = "incremental";
	public static final String PARAM_TIMEOUT = "timeout";
	public static final String PARAM_LINE_IDS = "lineIds";

	// Export to Excel
	public static final String PARAM_WORKBOOK_ZLIB = "workbook_B64ZLIB";

	public static final String PARAM_FILTER_CRITERIA = "criteria";
	public static final String PARAM_FILTER_CRITERIA_CONSTRUCTOR = "_constructor";
	public static final String PARAM_FILTER_CRITERIA_OPERATOR = "operator";
	public static final String PARAM_FILTER_CRITERIA_FIELDNAME = "fieldName";
	public static final String PARAM_FILTER_CRITERIA_VALUE = "value";
	public static final String PARAM_FILTER_CRITERIA_START = "start";
	public static final String PARAM_FILTER_CRITERIA_END = "end";
    public static final String PARAM_FILTERNODE_ID = "filterNodeId";
    public static final String PARAM_CONTEXT = "context";

	// mass edit
	public static final String PARAM_MASSEDIT_CRITERIA = "filterCriteria";
	public static final String PARAM_MASSEDIT_RECORDS = "massEditRecords";
	public static final String PARAM_MASSEDIT_FIELD = "fieldName";
	public static final String PARAM_MASSEDIT_VALUE = "fieldValue";
	public static final String PARAM_MASSEDIT_PRECISION = "precision";
	public static final String PARAM_MASSEDIT_OPERATOR = "massEditOperator";

	// mass action
	public static final String PARAM_MASSACTION_CRITERIA = "criteria";
	public static final String PARAM_MASSACTION_ACTION = "workflowAction";
	public static final String PARAM_MASSACTION_COMMENT = "comment";

	// mass delete
	public static final String PARAM_MASSDELETE_CRITERIA = "filterCriteria";

	//E-signature
	public static final String PARAM_OAUTH20_APIKEY = "apiKey";
	public static final String PARAM_OAUTH20_SECRETKEY = "secretKey";
	public static final String PARAM_OAUTH20_ACCESS_TOKEN = "accessToken";
	public static final String PARAM_OAUTH20_REFRESH_TOKEN = "refreshToken";
	public static final String PARAM_OAUTH20_AUTHENTICATED = "authenticated";

	public static final String PARAM_SIGNATURE_STATUS = "status";
	public static final String PARAM_SIGNATURE_ERROR = "error";
	public static final String PARAM_SIGNATURE_NOTE = "note";
	public static final String PARAM_SIGNATURE_SENDER = "sender";
	public static final String PARAM_SIGNATURE_SENDER_NAME = "senderName";
	public static final String PARAM_SIGNATURE_CUSTOMERNAME = "customerName";
	public static final String PARAM_SIGNATURE_CUSTOMERUSEROREMAIL = "customerUserOrEmail";



	// formula mgr
	public static final String PARAM_FM_KNOWNELEMENTS = "knownElements";
	public static final String PARAM_FM_TESTFORMULA = "testFormula";
	public static final String PARAM_FM_PRODUCT = "productSKU";
	public static final String PARAM_FM_ITEM = "item";
	public static final String PARAM_FM_ITEMS = "items";
	public static final String PARAM_FM_NATURE = "nature";
	public static final String PARAM_FM_NATURE_VALUE = "natureValue";
	public static final String PARAM_FM_NATURE_HEADERPHASES = "headerPhases";
	public static final String PARAM_FM_EXPRESSION = "formulaExpression";
	public static final String PARAM_FM_ALL_RESULTS = "allResults";
	public static final String PARAM_FM_TYPE = "type";
	public static final String PARAM_FM_DEBUGPORT = "debugPort";
	public static final String PARAM_FM_ALLOWOBJECTMODS = "allowObjectMods";
	public static final String PARAM_FM_SELECTEDROWS = "selectedRows";
	public static final String PARAM_FM_FORMULA_FILTER_PARAM = "formulaFilterParam";

	// account mgr
	public static final String PARAM_AM_ASSIGN = "assign";
	public static final String PARAM_AM_FROM = "from";
	public static final String PARAM_AM_TO = "to";

	// customer mgr
	public static final String PARAM_CM_FILTERCRITERIA = "filterCriteria";
	public static final String PARAM_CM_FILTERFORMULA = "filterFormula";

	// quote mgr
	public static final String PARAM_QM_QUOTE = "quote";
	public static final String PARAM_QM_FILTERCRITERIA = "filterCriteria";
	public static final String PARAM_QM_PARENT = "parent";
	public static final String PARAM_QM_TARGETSTATUS = "targetStatus";
	public static final String PARAM_QM_ITEMLIST = "itemList";
	public static final String PARAM_QM_MASS_UPDATE_CONFIG = "config";
	public static final String PARAM_QM_NAME = "name";
	public static final String PARAM_QM_APPROVALREQUIRED_EMAIL_ATTACHMENTS = "approvalRequiredEmailAttachments";

	// inline details view mgr
	public static final String PARAM_IDV_VIEW = "view";

	// contract mgr
	public static final String PARAM_CMGR_CONTRACT = "contract";
	public static final String PARAM_CMGR_CONTRACTTERMTYPES = "contractTermTypes";
	public static final String PARAM_CMGR_FILTERCRITERIA = "filterCriteria";
	public static final String PARAM_CMGR_PARENT = "parent";
	public static final String PARAM_CMGR_MASS_UPDATE_CONFIG = "config";

	// rebate mgr
	public static final String PARAM_RM_REBATEAGREEMENT = "rebateAgreement";
	public static final String PARAM_RM_REBATERECORD = "rebateRecord";
	public static final String PARAM_RM_REBATETYPES = "rebateTypes";
	public static final String PARAM_RM_FILTERCRITERIA = "filterCriteria";
	public static final String PARAM_RM_PARENT = "parent";

	// rebate agreements templates
	public static final String PARAM_RAT_INPUTPARAMS = "inputParameters";
	public static final String PARAM_RAT_PLACEHOLDERS = "placeholders";
	public static final String PARAM_RAT_TARGET_RA = "targetRA";
	public static final String PARAM_RAT_POINTERS = "pointers";
	public static final String PARAM_RAT_POINTER_PATH = "path";
	public static final String PARAM_RAT_POINTER_PLACEHOLDER = "placeholder";

	// deal planner
	public static final String PARAM_DPM_PLAN = "plan";
	public static final String PARAM_DPM_TARGETSTATUS = "targetStatus";

	// PO
	public static final String PARAM_PO_MODEL = "model";
	public static final String PARAM_PO_MODELRECORD = "modelRecord";

	// pricegrid mgr
	public static final String PARAM_PGM_IDS = "ids";
	public static final String PARAM_PGM_DENIALREASON = "denialReason";
	public static final String PARAM_PGM_CONFIGURATION = "configuration";
	public static final String PARAM_PGM_FILTERCRITERIA = "filterCriteria";

	// workflows mgr
	public static final String PARAM_WFM_ACTION_COMMENT = "actionComment";
	public static final String PARAM_WFM_ACTION_SELECTED_APPROVER = "actionSelectedApproverTypedId";
	public static final String PARAM_WFM_ACTION_ADDSTEP_PRECEDING_STEP_ID = "addStepCurrentStepId";
	public static final String PARAM_WFM_ACTION_ADDSTEP_STEP = "addStepStepInstance";
	public static final String PARAM_WFM_ACTION_SELECTED_STEP = "selectedStep";

	// pricelist mgr
	public static final String PARAM_PLM_CONFIGURATION = "configuration";
	public static final String PARAM_PLM_PRICELISTNAME = "priceListName";
	public static final String PARAM_PLM_ERRORMODE = "errorMode";
	public static final String PARAM_PLM_PARAMETERVALUES = "parameterValues";
	public static final String PARAM_PLM_PARAMETERS_OVERRIDE = "override";
	public static final String PARAM_PLM_KEEPMANUAL = "keepManualOverrides";
	public static final String PARAM_PLM_USEFILTERCRITERIA = "useFilter";
	public static final String PARAM_PLM_ONLYCHANGES = "writeOnlyChangedItems";
	public static final String PARAM_PLM_ITEMSTOAPPROVE = "itemsToApprove";
	public static final String PARAM_PLM_LISTSTOMERGE = "listsToMerge";

	// simulation mgr
	public static final String PARAM_SIM_CONVERTOBJECTS = "convertObjects";
	public static final String PARAM_SIM_SET = "simulationSet";
	public static final String PARAM_SIM_SKUFIELD = "skuField";

	// account mgr
	public static final String PARAM_AM_NEW_PASSWORD = "newPassword";
	public static final String PARAM_AM_OLD_PASSWORD = "oldPassword";

	// Workflow builder mgr
	public static final String PARAM_WFBM_APPROVABLE = "approvable";
	public static final String PARAM_WFBM_SUBMITTER = "submitter";

	// i18n mgr
	public static final String PARAM_I18NM_MESSAGES = "messages";

	// query mgr
	public static final String PARAM_QUERY_QUERIES = "queries";

	// dashboard mgr
	public static final String PARAM_PORTLETS = "portlets";
	public static final String PARAM_PORTLET_UNIQUENAME = "portletUniqueName";
	public static final String PARAM_PORTLET_LABEL = "portletLabel";
	public static final String PARAM_PORTLET_FORMULAEXPRESSION = "portletFormulaExpression";

	// emailtemplate manager
	public static final String PARAM_ETM_CONFIG = "config";

	// tree manager
	public static final String PARAM_TM_MAXDEPTH = "maxDepth";
	public static final String PARAM_TM_DELETETREEOBJECT = "deleteTreeObject";
	public static final String PARAM_TM_REMOVESUBTREE = "removeSubtree";
	public static final String PARAM_TM_CHILDREN = "children";

	public static final String PARAM_OBJREF_OBJID = "objRef_objId";
	public static final String PARAM_OBJREF_OBJBKEY = "objRef_objBKey";
	public static final String PARAM_OBJREF_OBJTYPE = "objRef_objType";
	// we don't store refs' directions in the db; that's why we need to specify the direction per fetch
	public static final String PARAM_OBJREF_ISOBJ1 = "objRef_isObj1";

	// param multitier
	public static final String PARAM_MT_SORTTYPE = "sortType";
	public static final String PARAM_MT_VALIDATIONTYPE = "validationType";

	public static final String PARAM_IMAGES = "images";

	//federation metadata
	public static final String PARAM_FMD_CERT_KEY = "signingCertificate";
	public static final String PARAM_FMD_IDP_KEY = "IdPURL";
	public static final String PARAM_FMD_URL = "fmdURL";

	// document data manager
	public static final String PARAM_DDM_FINAL = "final";
	public static final String PARAM_DDM_ATTACHED = "attached";

	/* Waterfall Datamart Query */

	/*
	 * Note: Labels are meaningless to server, but client use them for storage
	 * of meta information about projection. Goes together with idea of self
	 * contained query that will identify whole waterfall.
	 */

	/** Prefix of projection labels to identify the projection as price point. */
	public static final String QUERY_PRICEPOINT_PREFIX = "pp_";

	/** Prefix of projection labels to identify the projection as price point. */
	public static final String QUERY_POS_ADJUSTMENT_PREFIX = "pa_";
	public static final String QUERY_NEG_ADJUSTMENT_PREFIX = "na_";
	public static final String QUERY_AUTO_ADJUSTMENT_PREFIX = "aa_";

	/**
	 *
	 * FIELDS
	 *
	 */

	// generic fields
	public static final String FIELD_TYPEDID = "typedId";
	public static final String FIELD_ID = "id";
	public static final String FIELD_VERSION = "version";
	public static final String FIELD_UNIQUENAME = "uniqueName";
	public static final String FIELD_LABEL = "label";
    public static final String FIELD_LABELTRANSLATIONS = "labelTranslations";
	public static final String FIELD_NODEID = "nodeId";
	public static final String FIELD_PARENTID = "parentId";
	public static final String FIELD_PARENTTYPEDID = "parentTypedId";
	public static final String FIELD_ORDINAL = "ordinal";
	public static final String FIELD_OWNERTYPEDID = "ownerTypedId";
	public static final String FIELD_OWNER = "owner";
	public static final String FIELD_FILTERDESCRIPTION = "filterDescription";
	public static final String FIELD_TREENAME = "treeName";
	public static final String FIELD_OUTPUT = "output";
	public static final String FIELD_PARENT = "isParent";
	public static final String FIELD_VALIDAFTER = "validAfter";
	public static final String FIELD_USERGROUP = "userGroup";
	public static final String FIELD_USERGROUPEDIT = "userGroupEdit";
	public static final String FIELD_USERGROUPVIEWDETAILS = "userGroupViewDetails";
	public static final String FIELD_NAME = "name";
	public static final String FIELD_VALUE = "value";
	public static final String FIELD_TYPE = "type";
	public static final String FIELD_STATUS = "status";
	public static final String FIELD_INTEGRATIONSTATUS = "integrationStatus";
	public static final String FIELD_FORMATTYPE = "formatType";
	public static final String FIELD_SIMULATIONSET = "simulationSet";
	public static final String FIELD_TARGETDATE = "targetDate";
	public static final String FIELD_RELATIVETARGETDATE = "relativeTargetDateDays";
	public static final String FIELD_FORMULANAME = "formulaName";
	public static final String FIELD_WARNINGS = "warnings";
	public static final String FIELD_ALERTS = "alerts";
	public static final String FIELD_CALCULATIONRESULTS = "calculationResults";
	public static final String FIELD_LASTUPDATEDATE = "lastUpdateDate";
	public static final String FIELD_LASTUPDATEBY = "lastUpdateBy";
	public static final String FIELD_LASTUPDATEBYNAME = "lastUpdateByName";
	public static final String FIELD_CREATEDBY = "createdBy";
	public static final String FIELD_CREATEDBYNAME = "createdByName";
	public static final String FIELD_APPROVEDBYNAME = "approvedByName";
	public static final String FIELD_DENIEDBYNAME = "deniedByName";
	public static final String FIELD_SUBMITDATE = "submitDate";
	public static final String FIELD_SUBMITTEDBYNAME = "submittedByName";
	public static final String FIELD_SUPERSEDEDBY = "supersededBy";
	public static final String FIELD_PREVREV = "prevRev";
	public static final String FIELD_EXPIRYDATE = "expiryDate";
	public static final String FIELD_SKU = "sku";
	public static final String FIELD_UOM = "unitOfMeasure";
	public static final String FIELD_CURRENCY = "currency";
	public static final String FIELD_PRODUCTGROUP = "productGroup";
    public static final String FIELD_PRODUCTFIELDLABEL = "productGroup.productFieldLabel";
    public static final String FIELD_PRODUCTFIELDVALUE = "productGroup.productFieldValue";
    public static final String FIELD_PRODUCTFILTERSTRING = "productGroup.productFilterString";
	public static final String FIELD_PRODUCTFILTERLABEL = "productGroup.label";
	public static final String FIELD_SECONDARYKEY = "key2";
	public static final String FIELD_WATERFALLELEMENT = "waterfallElement";
	public static final String FIELD_ACTIVATED = "activated";
	public static final String FIELD_FILENAME = "fileName";
	public static final String FIELD_LENGTH = "length";
	public static final String FIELD_CATEGORY = "category";
	public static final String FIELD_DRAFT = "draft";
	public static final String FIELD_LISTID = "listId";
	public static final String FIELD_LISTLABEL = "listLabel";
	public static final String FIELD_ITEMTYPEDID = "itemTypedId";
	public static final String FIELD_TARGETOBJTYPECODE = "targetObjectTypeCode";
	public static final String FIELD_RESULTELEMENTNAME = "resultElementName";
	public static final String FIELD_ISPLASMA = "isPlasma";
	public static final String FIELD_INCONSISTENCY = "inconsistency";
	public static final String FIELD_SELECTED = "selected";

	public static final String FIELD_CREATEDATE = "createDate";
	public static final String FIELD_FORMULARESULT = "formulaResult";
	public static final String FIELD_COMPLETERESULTSAVAILABLE = "completeResultsAvailable";
	public static final String FIELD_FORMULADETAILEDRESULTS = "formulaDetailedResults";
	public static final String FIELD_PRIORITY = "priority";
	public static final String FIELD_WORKFLOWSTATUS = "workflowStatus";
	public static final String FIELD_COMMENT = "comments";
	public static final String FIELD_CONFIGURATION = "configuration";
	public static final String FIELD_APPROVALSTATE = "approvalState";
	public static final String FIELD_APPROVALDATE = "approvalDate";
	public static final String FIELD_DENIALDATE = "denialDate";
	public static final String FIELD_DENIALREASON = "denialReason";
	public static final String FIELD_VALID = "valid";
	public static final String FIELD_HIDE = "hide";
	public static final String FIELD_DYNAMIC_INPUTS = "dynamicInputs";

	public static final String FIELD_FLOWID = "flowId";
	public static final String FIELD_FLOWITEMID = "flowItemId";
	public static final String FIELD_APPROVAL_REASON = "approvalReason";
	public static final String FIELD_FLOWTRAINT_TRAITTYPE = "traitType";
	public static final String FIELD_FLOWTRAIT_PROCESSED = "processed";

	public static final String FIELD_AI1 = "additionalInfo1";
	public static final String FIELD_AI2 = "additionalInfo2";
	public static final String FIELD_AI3 = "additionalInfo3";
	public static final String FIELD_AI4 = "additionalInfo4";

	public static final String FIELD_DEPENDECY = "dependency";

	public static final String FIELD_NUMBEROFATTACHMENTS = "numberOfAttachments";

	public static final String FIELD_IMAGE = "image";

	public static final String FIELD_FORMAT = "format";

	// formula element
	public static final String FIELD_FE_INPUTDESCRIPTORS = "inputDescriptors";
	public static final String FIELD_FE_ELEMENTS = "elements";
	public static final String FIELD_FE_ELEMENTLABEL = "elementLabel";
	public static final String FIELD_FE_ELEMENTDESC = "elementDescription";
	public static final String FIELD_FE_ELEMENTGROUPS = "elementGroups";
	public static final String FIELD_FE_ELEMENTCONDITION = "conditionElementName";
	public static final String FIELD_FE_ELEMENTRESULT = "elementResult";
	public static final String FIELD_FE_DISPLAYOPTIONS = "displayOptions";
	public static final String FIELD_FE_COMBINATIONTYPE = "combinationType";
	public static final String FIELD_FE_FORMULAEXPRESSION = "formulaExpression";
	public static final String FIELD_FE_ELEMENTNAME = "elementName";
	public static final String FIELD_FE_CRITICALALERT = "criticalAlert";
	public static final String FIELD_FE_REDALERT = "redAlert";
	public static final String FIELD_FE_YELLOWALERT = "yellowAlert";
	public static final String FIELD_FE_HIDEWARNINGS = "hideWarnings";
	public static final String FIELD_FE_EXCLUDEFROMEXPORT = "excludeFromExport";
	public static final String FIELD_FE_ELEMENTTIMEOUT = "elementTimeout";
	public static final String FIELD_FE_ELEMENTSUFFIX = "elementSuffix";
	public static final String FIELD_FE_ALLOWOVERRIDE = "allowOverride";
	public static final String FIELD_FE_SUMMARIZE = "summarize";
	public static final String FIELD_FE_RESULTGROUP = "resultGroup";
	public static final String FIELD_FE_CSSPROPERTIES = "cssProperties";
	public static final String FIELD_FE_HIDEONNULL = "hideOnNull";
	public static final String FIELD_FE_FORMULANATURE = "formulaNature";
	public static final String FIELD_FE_TRANSLATIONS = "labelTranslations";
	public static final String FIELD_FE_PROTECTEDEXPRESSION = "protectedExpression";


	// workflow formula element
	public static final String FIELD_WFE_WORKFLOWTYPE = "workflowType";

	// user & roles
	public static final String FIELD_ROLE_PERMISSIONS = "permissions";
	public static final String FIELD_ROLE_MODULE = "module";
	public static final String FIELD_USER_LOGINNAME = "loginName";
	public static final String FIELD_USER_EMAIL = "email";
	public static final String FIELD_USER_FIRST_NAME = "firstName";
	public static final String FIELD_USER_FULL_NAME = "fullName";
	public static final String FIELD_USER_LAST_NAME = "lastName";
	public static final String FIELD_USER_LASTLOGIN = "lastLogin";
	public static final String FIELD_USER_FIRSTLOGIN = "firstLogin";
	public static final String FIELD_USER_NAME = "name";
	public static final String FIELD_USER_ROLENAMES = "roleNames";
	public static final String FIELD_USER_ALLROLENAMES = "allRoleNames";
	public static final String FIELD_USER_WORKFLOWEMAILINGSACTIVATED = "workflowEmailingActivated";
	public static final String FIELD_USER_EMAILLOCALE = "emailLocale";
	public static final String FIELD_USER_GROUPS = "groups";
	public static final String FIELD_USER_ALLGROUPS = "allGroups";
	public static final String FIELD_USER_BUSINESSROLES = "businessRoles";
	public static final String FIELD_USER_DEFAULTUSERGROUP_EDIT = "defaultUserGroupEdit";
	public static final String FIELD_USER_DEFAULTUSERGROUP_VIEW = "defaultUserGroupViewDetails";
	public static final String FIELD_USER_EXTDATA = "extendedData";
	public static final String FIELD_USER_PRODFILTER = "productFilterCriteria";
	public static final String FIELD_USER_CUSTFILTER = "customerFilterCriteria";
	public static final String FIELD_USER_WIZARDNAME = "wizardDashboardName";
	public static final String FIELD_USER_NOSESSION = "noSession";
	public static final String FIELD_USER_PWDEXPIRY = "passwordExpiry";
	public static final String FIELD_USER_TFA = "requireTFA";
	public static final String FIELD_USER_RECADMINEMAIL = "receiveAdminEmail";
	public static final String FIELD_USER_SSOONLY = "ssoOnly";

	public static final String FIELD_TFA_SENTTO = "sentToEmail";

	public static final String USEREXTDATA_OPENTODOS = "numberOfOpenToDo";
	public static final String USEREXTDATA_HASTODOS = "hasToDo";
	public static final String USEREXTDATA_DCRTYPES = "dcrTypes";
	public static final String USEREXTDATA_CONFWIZARDS = "configurationWizards";
	public static final String USEREXTDATA_HASAPPROVABLES = "hasApprovables";
	public static final String USEREXTDATA_HASPENDINGCREATIONWORKFLOW = "hasPendingCreationWorkflows";
	public static final String USEREXTDATA_HASACTIVEQUOTEPRODUCTFILTER = "hasActiveQuoteProductFilter";
	public static final String USEREXTDATA_ACTIVE_MODULES = "activeModules";
	public static final String USEREXTDATA_DE_NATURE_PREFIX = "detailsEditor_";
	public static final String USEREXTDATA_CLUSTERNAME = "clusterName";
	public static final String USEREXTDATA_MAXFORMSIZE = "maxFormSize";
	public static final String USEREXTDATA_BASECURRENCY = "baseCurrency";
	public static final String USEREXTDATA_USEREDISLOGS = "useRedisLogs";


	public static final String FIELD_DCRMC_MASS_CHANGE = "massChange";
	public static final String FIELD_DCRMC_MASS_CHANGE_FILTER = "filter";
	public static final String FIELD_DCRMC_MASS_CHANGE_TYPE = "type";
	public static final String FIELD_DCRMC_MASS_CHANGE_DEFINITIONS = "definitions";
	public static final String FIELD_DCRI_CHANGE_REF = "changeRef";

	//todo items
	public static final String FIELD_TODO_DESCRIPTION = "description";
	public static final String FIELD_TODO_DUEDATE = "dueDate";
	public static final String FIELD_TODO_COMPLETEDDATE = "completedDate";
	public static final String FIELD_TODO_TARGETOBJECT = "targetObject";
	public static final String FIELD_TODO_TARGETPAGE = "targetPage";
	public static final String FIELD_TODO_TARGETPAGESTATE = "targetPageState";
	public static final String FIELD_TODO_TARGETPAGECOMPONENT = "targetPageComponent";
	public static final String FIELD_TODO_ASSIGNEDTONAME = "assignedToName";
	public static final String FIELD_TODO_ASSIGNEDTOGROUP = "assignedToGroup";

	//data change request
	public static final String FIELD_DCR_TARGETOBJNAME = "targetObjectName";
	public static final String FIELD_DCR_TARGETOBJID = "targetObjectTypedId";
	public static final String FIELD_DCR_TYPE = "dcrTypeName";
	public static final String FIELD_DCR_ID = "changeRequestId";
	public static final String FIELD_DCR_DELETEROW = "deleteRow";
	public static final String FIELD_DCR_OLDVALUES = "oldValues";
	public static final String FIELD_DCR_IGNORECHANGE = "ignoreChange";
	public static final String FIELD_DCR_TARGETTYPE = "dcrTargetType";
	public static final String FIELD_DCR_TARGETINFO = "dcrTargetInfo";

	//Document data
	public static final String FIELD_DDM_OBJECTID = "objectId";
	public static final String FIELD_DDM_OBJECTTYPE = "objectType";
	public static final String FIELD_DDM_DOCTYPEDID = "docTypedId";
	public static final String FIELD_DDM_DOCUMENTID = "documentId";
	public static final String FIELD_DDM_DOCUMENTTYPE = "documentType";
	public static final String FIELD_DDM_LINEID = "lineId";
	public static final String FIELD_DDM_FINAL = "isFinal";



	// Inline Details Configuration
	public static final String FIELD_IDC_TARGETOBJNAME = "targetObjectName";
	public static final String FIELD_IDC_TARGETOBJID = "targetObjectTypedId";
	public static final String FIELD_IDC_FORMULANAME = "formulaName";
	public static final String FIELD_IDC_PAYLOAD = "payload";

	//email
	public static final String FIELD_ET_BODY = "body";
	public static final String FIELD_ET_SUBJECT = "subject";
	public static final String FIELD_ET_RECIPIENT = "recipient";
	public static final String FIELD_ET_RECIPIENTS = "recipients";
	public static final String FIELD_ET_SENT = "sent";
	public static final String FIELD_ET_RETRIESLEFT = "retriesLeft";
	public static final String FIELD_ET_REPLYTO = "replyTo";
	public static final String FIELD_ET_SENDER = "sender";
	public static final String FIELD_ET_SOURCE_OBJECT = "sourceObject";

	//event
	public static final String FIELD_EVT_MESSAGE = "message";
	public static final String FIELD_EVT_RETRIESLEFT = "retriesLeft";
	public static final String FIELD_EVT_HTTPRESP = "httpResponse";
	public static final String FIELD_EVT_ERRORMSG = FIELD_ERRORMSG;

	//preferences
	public static final String FIELD_PREF_TYPE = "preferenceType";
	public static final String FIELD_PREF_NAME = "preferenceName";
	public static final String FIELD_PREF_GLOBAL = "areGlobal";
	public static final String FIELD_PREF_DEFAULT = "areDefault";
	public static final String FIELD_PREF_VIEWSTATE = "viewState";
	public static final String FIELD_PREF_FILTER = "filter";
	public static final String FIELD_PREF_HASFILTER = "hasFilter";
	public static final String FIELD_PREF_COLUMNLABELS = "columnLabels";

	// lookup tables
	public static final String FIELD_LT_TYPE = "type";
	public static final String FIELD_LT_VALUETYPE = "valueType";
	public static final String FIELD_LT_HIDEWARNINGS = "hideWarnings";
	public static final String FIELD_LTV_TABLEID = "lookupTable_id";
	public static final String FIELD_LTV_TABLE_ID = "lookupTable.id";
	public static final String FIELD_LTV_NAME = "name";
	public static final String FIELD_LTV_VALUE = "value";
	public static final String FIELD_LTV_KEY_PREFIX = "key";
	public static final String FIELD_LTV_LOWERBOUND = "lowerBound";
	public static final String FIELD_LTV_UPPERBOUND = "upperBound";
	public static final String FIELD_MLTVM_TABLEID = "lookupTableId";

	// alert
	public static final String FIELD_ALERT_OPERATOR = "operator";
	public static final String FIELD_ALERT_THRESHOLD = "threshold";
	public static final String FIELD_ALERT_MESSAGE = "message";
	public static final String FIELD_ALERT_COMPARISONELEMENT = "comparisonElement";

	// customer
	public static final String FIELD_CUSTOMER_ID = "customerId";
	public static final String FIELD_CUSTOMERGROUP = "customerGroup";
	public static final String FIELD_CUSTOMERFIELDLABEL = "customerGroup.customerFieldLabel";
    public static final String FIELD_CUSTOMERFIELDVALUE = "customerGroup.customerFieldValue";
    public static final String FIELD_CUSTOMERFILTERSTRING = "customerGroup.customerFilterString";
	public static final String FIELD_CUSTOMERFILTERLABEL = "customerGroup.label";
	public static final String FIELD_ASSIGNMENT = "assignment";
	public static final String FIELD_ASSIGNMENTTYPE = "assignmentType";

	//api key
	public static final String FIELD_APIKEY_KEY = "apiKey";
	public static final String FIELD_APIKEY_EXPIRY = "expiry";
	public static final String FIELD_APIKEY_RENEWRT = "renewRefreshToken";
	public static final String FIELD_APIKEY_REGENABLED = "registrationEnabled";
	public static final String FIELD_APIKEY_MAXATTEMPTS = "maxAttempts";
	public static final String FIELD_APIKEY_PUBRSA = "rsaPublic";
	public static final String FIELD_APIKEY_PRIVRSA = "rsaPrivate";
	public static final String FIELD_APIKEY_PARTITIONNAMES = "partitionNames";

	//price API jobs
	public static final String FIELD_PAPI_JOBID = "jobId";
	public static final String FIELD_PAPI_PAID = "paidCredits";
	public static final String FIELD_PAPI_FREE = "freeCredits";
	public static final String FIELD_PAPI_TASKNAME = "taskName";
	public static final String FIELD_PAPI_TRACKERUUID = "trackerUUID";

	//price config wizards
	public static final String FIELD_CW_WIZARDFORMULA = "wizardFormula";
	public static final String FIELD_CW_EXECFORMULA = "executionFormula";
	public static final String FIELD_CW_USERGROUP = "userGroup";

	// partition
	public static final String FIELD_P_MAXADMIN = "maxAdminUsers";
	public static final String FIELD_P_MAXPB = "maxPriceBuilderUsers";
	public static final String FIELD_P_MAXPS = "maxPriceShopUsers";
	public static final String FIELD_P_MAXANALYTICS = "maxAnalyticsUsers";
	public static final String FIELD_P_MAXRM = "maxRebateManagerUsers";
	public static final String FIELD_P_MAXCM = "maxClaimManagerUsers";
	public static final String FIELD_P_MAXPM = "maxContractManagerUsers";
	public static final String FIELD_P_MAXPO = "maxPriceOptimizationUsers";
	public static final String FIELD_P_MAXLDO = "maxDealPlannerUsers";
	public static final String FIELD_P_PADBHOSTS = "paDbHosts";
	public static final String FIELD_P_PADBNAME = "paDbName";
	public static final String FIELD_P_BASECURRENCY = "baseCurrencyCode";
	public static final String FIELD_P_BASEUOM = "baseUOMCode";
	public static final String FIELD_P_EVENTSTOKAFKA = "eventsToKafka";
	public static final String FIELD_P_EVENTBITMASK = "eventBitMask";
	public static final String FIELD_P_CSENABLED = "csEnabled";
	public static final String FIELD_P_DISABLE_BGJOBS = "disableBackgroundJobs";
	public static final String FIELD_P_GLOBALPARTITION = "globalPartitionName";
	public static final String FIELD_P_GLOBALEXTENSIONS = "globalPartitionExtensions";
	public static final String FIELD_P_GLOBALTYPES = "globalObjectTypes";
	public static final String FIELD_P_CSRF_BLOCKER_ENABLED = "csrfBlockerEnabled";
	public static final String FIELD_P_CSRF_BLOCKER_USER_AGENT_EXCLUSIONS = "csrfBlockerUserAgentExclusions";
	public static final String FIELD_P_CUSTOMSCHEMA = "customSchemaInfo";
	public static final String FIELD_P_ADMINUSERPASS = "adminUserPass";	//optional

	public static final String FIELD_CN_SERVERROLES = "serverRoles";
	public static final String FIELD_CN_UPGRADE_FAILOVER_SERVER_ROLES = "upgradeFailoverServerRoles";
	public static final String FIELD_CN_CALCPARTITIONS = "calcPartitions";
	public static final String FIELD_CN_PADATALOADPARTITIONS = "paDataLoadPartitions";
	public static final String FIELD_CN_PAQUERYPARTITIONS = "paQueryPartitions";
	public static final String FIELD_CN_HOSTINFO = "hostInfo";
	public static final String FIELD_CN_LASTJOIN = "lastJoinDate";
	public static final String FIELD_CN_LASTSEEN = "lastSeenDate";
	public static final String FIELD_CN_MAINTENANCEMODE = "maintenanceMode";
	public static final String FIELD_CN_HOST = "jettyHost";
	public static final String FIELD_CN_PORT = "jettyPort";

	// bound partitions
	public static final String FIELD_BPT_BASEURL = "baseUrl";
	public static final String FIELD_BPT_USERNAME = "userName";
	public static final String FIELD_BPT_PARTITIONNAME = "partitionName";
	public static final String FIELD_BPT_PASSWORD = "password";
	public static final String FIELD_BPT_INTEGRATIONHOST = "integrationHost";
	public static final String FIELD_BPT_INTEGRATIONPORT = "integrationPort";


	// calculatable object status
	public static final String FIELD_CO_STATUS = "status";
	public static final String FIELD_CO_CAlCULATION_DATE = "calculationDate";
	public static final String FIELD_CO_CAlCULATION_STARTDATE = "calculationStartDate";
	public static final String FIELD_CO_NUMBEROFITEMS = "numberOfItems";
	public static final String FIELD_CO_CALCMESSAGES = "calculationMessages";
	public static final String FIELD_CO_SCHEDULES = "schedules";
	public static final String FIELD_CO_ISDEFAULT = "isDefault";

	// PriceList, PriceGrid, Simulation summary

	public static final String FIELD_CO_SUMMARY_QUERY = "query";
	public static final String FIELD_CO_SUMMARY_OBJECTS = "objects";
	public static final String FIELD_CO_SUMMARY_PROJECTIONS = "projections";
	public static final String FIELD_CO_SUMMARY_COUNT = "count";
	public static final String FIELD_CO_SUMMARY_PRODUCTGROUPBY = "productGroupBy";
	public static final String FIELD_CO_SUMMARY_PRODUCTFILTER = "productFilter";
	public static final String FIELD_CO_SUMMARY_ITEMGROUPBY = "itemGroupBy";
	public static final String FIELD_CO_SUMMARY_ITEMFILTER = "itemFilter";
	public static final String FIELD_CO_SUMMARY_FIELDNAME = "fieldName";
	public static final String FIELD_CO_SUMMARY_WEIGHT = "weight";
	public static final String FIELD_CO_SUMMARY_AGGREGATIONMODE = "aggregationMode";

	// calculable item fields
	public static final String FIELD_CI_ALERTS_TYPE_MAP_POSTFIX = "_ALERT_TYPE";
	public static final String FIELD_CI_RESULTPRICE = "resultPrice";
	public static final String FIELD_CI_MANUALPRICE = "manualResultPrice";
	public static final String FIELD_CI_PREVIOUSPRICE = "previousPrice";
	public static final String FIELD_CI_PRICECHANGEABS = "priceChange";
	public static final String FIELD_CI_PRICECHANGEPCT = "priceChangePct";
	public static final String FIELD_CI_MANUALOVERRIDES = "manualOverrides";
	public static final String FIELD_CI_ALLOWEDOVERRIDES = "allowedOverrides";
	public static final String FIELD_CI_EXTENSIONS = "itemExtensions";
	public static final String FIELD_CI_WORKSTATUS = "workStatus";
	public static final String FIELD_CI_KEY2 = "key2";

	// calculated field set
	public static final String FIELD_CFS_FAILEDITEMS = "numberOfFailedItems";

	// pricelist
	public static final String FIELD_PL_ERRORMODE = "errorMode";
	public static final String FIELD_PL_PREVIOUSID = "previousPricelistId";
	public static final String FIELD_PL_DESCRIPTION = "description";
	public static final String FIELD_PL_LAST_UPDATE_BY = "lastUpdateBy";
	public static final String FIELD_PL_PLTYPE = "pricelistType";
	public static final String FIELD_PL_EXPORTDATE = "exportDate";


	public static final String FIELD_PLI_PRICELISTID = "pricelistId";

	public static final String FIELD_MPL_CFSLINK = "linkedCFStypedId";

	public static final String FIELD_PG_APPROVEDITEMS = "numberOfApprovedItems";
	public static final String FIELD_PG_OPENITEMS = "numberOfOpenItems";
	public static final String FIELD_PG_DENIEDITEMS = "numberOfDeniedItems";
	public static final String FIELD_PG_AAITEMS = "numberOfAutoApprovedItems";
	public static final String FIELD_PG_SUBMITTEDITEMS = "numberOfSubmittedItems";
	public static final String FIELD_PG_PARTIALCALCDATE = "partialCalculationDate";
	public static final String FIELD_PG_TYPE = "priceGridType";


	public static final String FIELD_PGI_PRICEGRIDID = "priceGridId";
	public static final String FIELD_PGI_PRICECHANGEABS_PREV = "priceChange_ActivePrev";
	public static final String FIELD_PGI_PRICECHANGEPCT_PREV = "priceChangePct_ActivePrev";
	public static final String FIELD_PGI_ACTIVEPRICE = "activePrice";
	public static final String FIELD_PGI_ACTIVEPRICEDATE = "activePriceDate";
	public static final String FIELD_PGI_PREVIOUSPRICEDATE = "previousPriceDate";
	public static final String FIELD_PGI_MANUALPRICEEXPIRED = "manualPriceExpired";

	// Simulation
	public static final String FIELD_SIM_BASECO = "baseCO";
	public static final String FIELD_SIM_KEEPOVERRIDES = "keepManualOverrides";
	public static final String FIELD_SIM_USEFILTERCRITERIA = "useFilterCriteria";
	public static final String FIELD_SIM_ONLYCHANGES = "writeOnlyChangedItems";
	public static final String FIELD_SIM_IGNORESECKEYFILTERING = "ignoreSecKeyFiltering";
	public static final String FIELD_SIM_SHOTGUNMODEENABLED = "shotgunModeEnabled";
	public static final String FIELD_SIM_SIMULATIONID = "simulationId";
	public static final String FIELD_SIM_BASECOTYPE = "baseCOType";
	//virtual fields
	public static final String FIELD_SIM_PRICELISTID = "basePricelistId";
	public static final String FIELD_SIM_PRICEGRIDID = "basePriceGridId";


	// BOM
	public static final String FIELD_BOM_QUANTITY = "quantity";
	public static final String FIELD_BOM_CATEGORY = "category";
	public static final String FIELD_BOM_RAWMAT = "rawMaterial";
	public static final String FIELD_BOM_SUBCOMPONENT = "subComponentSku";
	public static final String FIELD_BOM_PARENTSKU = "parentSku";
	public static final String FIELD_BOM_PARENTBOMID = "parentBoMId";
	public static final String FIELD_BOM_TREEID = "id";
	public static final String FIELD_BOM_TREEPARENT = "parentId";
	public static final String FIELD_BOM_TYPE = "type";

	// Product & Customer Details
	public static final String FIELD_PDETAIL_COMPETITORSKU = "competitorSku";
	public static final String FIELD_PDETAIL_COMPETITOR = "competitor";
	public static final String FIELD_PDETAIL_PRICE = "price";
	public static final String FIELD_PDETAIL_PRICETYPE = "priceType";
	public static final String FIELD_PDETAIL_PRICEUNIT = "priceUnit";
	public static final String FIELD_PDETAIL_COMPETITIONTYPE = "competitionType";
	public static final String FIELD_PDETAIL_INFODATE = "infoDate";
	public static final String FIELD_PDETAIL_TARGETSKU = "targetSku";
	public static final String FIELD_PDETAIL_REFTYPE = "referenceType";
	public static final String FIELD_PDETAIL_SOURCE = "source";
	public static final String FIELD_PDETAIL_COUNTRY = "country";
	public static final String FIELD_PDETAIL_INTERNALREF = "internalReference";
	public static final String FIELD_PDETAIL_PARENTTYPEDID = "parentTypedId";
	public static final String FIELD_PDETAIL_PARENTLABEL = "parentLabel";


	public static final String FIELD_OBJDETAIL_DESCRIPTION = "description";

	// CLICs
	public static final String FIELD_CLIC_ROOTUNIQUENAME = "rootUniqueName";
	public static final String FIELD_CLIC_SUPERSEDEDBYUN = "supersededByUN";
	public static final String CLIC_UNIQUENAME_REVISION_SEPARATOR = "-v";
	public static final String FIELD_CLIC_ADDEDLINEIDS = "addedLineIds";
	public static final String FIELD_CLIC_INCORRECTSKUS = "incorrectSKUs";
	public static final String FIELD_CLIC_INCORRECTITEMS = "incorrectItems";
	public static final String FIELD_CLIC_CREATION_WORKFLOW_STATUS = "creationWorkflowStatus";
	public static final String FIELD_CLIC_CREATION_WORKFLOW_CURRENT_STEP = "creationWorkflowCurrentStep";
	public static final String FIELD_CLIC_CREATION_WORKFLOW_STEP_COUNT = "creationWorkflowStepCount";
	public static final String FIELD_CLIC_CREATION_WORKFLOW_STEP_LABEL = "creationWorkflowStepLabel";
	public static final String FIELD_CLIC_LINEID = "lineId";
	public static final String FIELD_SERVER_MESSAGES = "serverMessages";

	// Quotes
	public static final String FIELD_Q_EXTREF = "externalRef";
	public static final String FIELD_Q_STATUS = "quoteStatus";
	public static final String FIELD_Q_CUSTOMERNAME = "customerName";
	public static final String FIELD_Q_QUOTETYPE = "quoteType";
	public static final String FIELD_Q_QUOTETYPEUN = "quoteTypeUniqueName";

	//Quote Types
	public static final String FIELD_QTT_HEADERFORMULANAME = "headerFormulaName";
	public static final String FIELD_QTT_WORKFLOWFORMULANAME = "workflowFormulaName";
	public static final String QTT_DEFAULT_QUOTETYPE_NAME = "Default";

	// pending creation workflows (assigned to user)
	public static final String FIELD_PCWF_USERLOGINNAME = "userLoginName";
	public static final String FIELD_PCWF_DOCUMENTTYPEDID = "documentTypedId";
	public static final String FIELD_PCWF_DOCUMENTUNIQUENAME = "documentUniqueName";
	public static final String FIELD_PCWF_DOCUMENTLABEL = "documentLabel";
	public static final String FIELD_PCWF_STEPLABEL = "stepLabel";

	// Price records
	public static final String FIELD_PR_SOURCEID = "sourceId";
	public static final String FIELD_PR_SOURCEID_NOREV = "sourceIdNoRev";
	public static final String FIELD_PR_LINEID = "lineId";

	// Workflows
	public static final String FIELD_WF_APPROVABLETYPEDID = "approvableTypedId";
	public static final String FIELD_WF_CURRENTSTEPID = "currentStepId";
	public static final String FIELD_WF_APPROVABLEPARENTTYPEDID = "approvableParentTypedId";
	public static final String FIELD_WF_STATUS = "workflowStatus";
	public static final String FIELD_WF_APPROVABLEUNIQUENAME = "approvableUniqueName";
	public static final String FIELD_WF_DELEGATION = "delegation";
	public static final String FIELD_WF_NOTIFICATIONSENT = "notificationSent";
	public static final String FIELD_WF_CODE = "code";

	//WorkflowDelegation
	public static final String FIELD_WD_SOURCEUSER = "sourceUser";
	public static final String FIELD_WD_TARGETUSER = "targetUser";
	public static final String FIELD_WD_SOURCEUSERID = "sourceUserId";
	public static final String FIELD_WD_TARGETUSERID = "targetUserId";
	public static final String FIELD_WD_STARTDATE = "startDate";
	public static final String FIELD_WD_ENDDATE = "endDate";
	public static final String FIELD_WD_STATUS = "status";
	public static final String FIELD_WD_CREATEDBYADMIN = "createdByAdmin";
	public static final String FIELD_WD_NOTE = "note";

	// Rebates
	public static final String FIELD_RBA_STATUS = "rebateAgreementStatus";
	public static final String FIELD_RBA_STARTDATE = "startDate";
	public static final String FIELD_RBA_ENDDATE = "endDate";
	public static final String FIELD_RBA_PAYOUTDATE = "payoutDate";
	public static final String FIELD_RBA_CALCULATIONDATE = "calculationDate";
	public static final String FIELD_RBA_REBATETYPE = "rebateType";
	public static final String FIELD_RBA_REBATETYPEUN = "rebateTypeUN";
	public static final String FIELD_RBA_HEADERREBATETYPE = "headerRebateType";
	public static final String FIELD_RBA_HEADERREBATETYPEUN = "headerRebateTypeUniqueName";

	// Rebate Record
	public static final String FIELD_RR_DESCRIPTION = "description";
	public static final String FIELD_RR_REBATERECORDSETID = "rebateRecordSetId";
	public static final String FIELD_RR_REBATERECORDSETLABEL = "rebateRecordSetLabel";
	public static final String FIELD_RR_MESSAGES = "messages";
	public static final String FIELD_PR_RR_UNIQUENAME= "rebateRecordUN";

	public static final String FIELD_RR_SOURCEID = "sourceId";
	public static final String FIELD_RR_SOURCEID_NOREV = "sourceIdNoRev";
	public static final String FIELD_RR_LINEID = "lineId";
	public static final String FIELD_RR_INPUTS = "inputs";
	public static final String FIELD_RR_AGREEMENTSTATUS = "agreementStatus";
	public static final String FIELD_RR_AGREEMENTTERMS = "agreementTerms";
	public static final String FIELD_RR_CALCULATIONBASEFILTER = "calculationBaseAsAdvancedFilterCriteria";

	public static final String FIELD_RR_DTOFILTER = "dtoFilter";
	public static final String FIELD_RR_SORTBY = "sortBy";
	public static final String FIELD_RR_INCCALCULATIONDATE = "incCalculationDate";
	public static final String FIELD_RR_RANK = "rank";
	public static final String FIELD_RR_INTEGRATION_STATUS = "intgStatus";
	public static final String FIELD_RR_INTEGRATION_STATUSDETAILS = "intgStatusDetails";
	public static final String FIELD_RR_INTEGRATION_STATUSERPREFERENCE = "intgStatusErpReference";

	public static final String RR_DEFAULT_RECORDSET_LABEL = "Default";
	public static final String FIELD_RR_REBATE_TYPE = "rebateType";
	public static final String FIELD_RR_REBATE_TYPE_UN = "rebateTypeUN";

	// Model Record
	public static final String FIELD_MR_MODELID = "modelId";

	// Contracts
	public static final String FIELD_CONTRACT_EXTREF = "externalRef";
	public static final String FIELD_CONTRACT_STATUS = "contractStatus";
	public static final String FIELD_CONTRACT_STARTDATE = "startDate";
	public static final String FIELD_CONTRACT_ENDDATE = "endDate";
	public static final String FIELD_CONTRACT_CONTRACTTYPE = "contractTermType";
	public static final String FIELD_CONTRACT_CONTRACTTYPEUN = "contractTermTypeUniqueName";

	// Claims
	public static final String FIELD_CLAIM_TYPE = "claimType";
	public static final String FIELD_CLAIM_RECORD = "claimRecord";
	public static final String FIELD_CLAIM_EXTREF = "externalRef";
	public static final String FIELD_CLAIM_FILEHANDLE = "fileHandle";
	public static final String FIELD_CLAIM_FILENAME = "fileName";
	public static final String FIELD_CLAIM_SOURCECONTRACT_UNIQUENAME = "sourceContractUniqueName";
	public static final String FIELD_CLAIM_SOURCEQUOTE_UNIQUENAME = "sourceQuoteUniqueName";
	public static final String FIELD_CLAIM_ITEM_VALIDATIONSTATE = "validationState";
	public static final String FIELD_CLAIM_ITEM_TOTALAMOUNT = "totalAmount";
	public static final String FIELD_CLAIM_ITEM_CONTRACT_UNIQUENAME = "contractUniqueName";
	public static final String FIELD_CLAIM_ITEM_QUOTE_UNIQUENAME = "quoteUniqueName";
	public static final String FIELD_CLAIM_ITEM_ENDCUSTOMERID = "endCustomerId";
	public static final String FIELD_CLAIM_ITEM_QUANTITY = "quantity";
	public static final String FIELD_CLAIM_STATUS = "claimStatus";
    public static final String FIELD_CLT_SHEETNAME = "sheetName";
    public static final String FIELD_CLT_ALLOCATION_FORMULA = "allocationFormulaName";
	public static final String FIELD_CLT_VALIDATION_STATE_ELEMEMT_NAME = "validationStateElementName";
	public static final String FIELD_CLR_SOURCEID = "sourceId";
	public static final String FIELD_CLR_ITEMCOUNT = "itemCount";

	public static final String FIELD_CLAIM_ID = "claimId";
	public static final String FIELD_CALCULATION_STATUS = "calculationStatus";

	// Price List Type
	public static final String FIELD_PLPGTT_HEADERTYPEUNIQUENAME = "headerTypeUniqueName";
	public static final String FIELD_PLPGTT_HEADERFORMULANAME = "headerFormulaName";
	public static final String FIELD_PLPGTT_DEFAULTVIEWPREF = "preferences";
	public static final String FIELD_PLPGTT_TYPE = "targetType";

	// Calendar
	public static final String FIELD_CAL_CALCULABLETYPEDID = "calculableTypedId";
	public static final String FIELD_CAL_CALCULABLELABEL = "calculableLabel";
	public static final String FIELD_CAL_STARTDATE = "startDate";
	public static final String FIELD_CAL_PERIOD = "period";
	public static final String FIELD_CAL_INTERVAL = "interval";

	// Deal Plans
	public static final String FIELD_DEALPLAN_TYPE = "dealPlanType";
	public static final String FIELD_DEALPLAN_LINKED_TYPEDIDS = "linkedTypedIds";
	public static final String FIELD_DEALPLANROUND_NEGOTIATIONDATE = "negotiationDate";
	public static final String FIELD_DEALPLANTYPE_HEADERFORMULANAME = "headerFormulaName";


	// datamart
	public static final String FIELD_LOADDATA_DIGEST = "digest";
	public static final String FIELD_LOADDATA_HEADER = "header";
	public static final String FIELD_LOADDATA_DATA = "data";
	public static final String FIELD_LOADDATA_OPTIONS = "options";
	public static final String FIELD_LOADDATA_OPTIONS_IGNOREDUPLICATES = "ignoreDuplicates";
	public static final String FIELD_LOADDATA_OPTIONS_DIRECT2DS = "direct2ds";

	// sellers
	public static final String FIELD_SELLER_NAME = "sellerName";
	public static final String FIELD_SELLER_ID = "sellerId";

	public static final String FIELD_DM_MESSAGES = "messages";
	public static final String FIELD_DM_DEPLOYED = "deployed";
	public static final String FIELD_DM_VIEW = "view";
    public static final String PARAM_DM_SOURCE$QUERY = "source$query";  // source-query param in a format so as to not clash with any clientRequest.data filter criteria (FC.field = ...)
	public static final String PARAM_DM_QUERY = "query";
	public static final String PARAM_DM_QUERYDTO = "queryDto";
	public static final String PARAM_DM_QUERIES = "queries";
	public static final String PARAM_DM_JOINKEYS = "joinKeys";
	public static final String PARAM_DM_DATAMART = "datamart";		// obsolete - now use "source", but maintained for backwards compatibility
	public static final String PARAM_DM_SOURCE = "source";			//
	public static final String PARAM_DM_FORMULA = "formula";
	public static final String PARAM_DM_PROJECTIONS = "projections";
	public static final String PARAM_DM_NAME = "name";
	public static final String PARAM_DM_DOROLLUP = "rollup";
	public static final String PARAM_DM_ADVANCED_PROJECTION = "advancedProjection";
	public static final String PARAM_DM_FUNCTION = "function";
	public static final String PARAM_DM_EXPRESSION = "expression";
	public static final String PARAM_DM_PARAMETERS = "parameters";
	public static final String PARAM_DM_DEFAULT = "default";
	public static final String PARAM_DM_PIVOT = "pivot";
	public static final String PARAM_DM_COMPARE = "compare";
	public static final String PARAM_DM_FILTER = "filter";
	public static final String PARAM_DM_AGGREGATEFILTER = "aggregateFilter";
	public static final String PARAM_DM_DIMFILTERS = "dimensionFilters";
	public static final String PARAM_DM_OPTIONS = "options";
	public static final String PARAM_DM_DISTINCT_VALUES = "distinctValues";
	public static final String PARAM_DM_DISCRETIZATION = "discretization";
	public static final String PARAM_DM_DISTRIBUTION = "distribution";
	public static final String PARAM_DM_NORMALIZATION = "normalization";
	public static final String PARAM_DM_REGRESSION = "regression";
	public static final String PARAM_DM_STATISTICS = "statistics";
	public static final String PARAM_DM_SELECTDATA = "selectData";
	public static final String PARAM_DM_BINS = "bins";
	public static final String PARAM_DM_CURRENCYCODE = "currency";
	public static final String PARAM_DM_ROWLIMIT = "limit";
	public static final String PARAM_DM_DISTINCTROWS = "distinctRows";

	public static final String PARAM_DM_SCHEMA_RESERVEDWORDS = "reservedWords";
	public static final String PARAM_DM_SCHEMA_CURRENCIES = "currencies";
	public static final String PARAM_DM_SCHEMA_UOMS = "uoms";

	public static final String PARAM_MAXDEPTH = "maxDepth";
	public static final String PARAM_MAXNODES = "maxNodes";

	public static final String FIELD_DM_NAME = "name";
	public static final String FIELD_DM_DIMVALUE_OTHER = "[Other]";
	public static final String FIELD_DM_DIMVALUE_NA = "[N/A]";
	public static final String FIELD_DM_NUMVALUE_NaN = "NaN";
	public static final String FIELD_DM_BINFREQUENCY = "binFreq";
	public static final String FIELD_DM_BINLABEL = "binLabel";
	public static final String FIELD_DM_CHARTTYPE = "chartType";
	public static final String FIELD_DM_VISIBILITY = "visibility";
	public static final String FIELD_DM_CHARTDESCRIPTION = "description";
	public static final String FIELD_DM_CHARTDEFINITION = "chartDefinition";
	public static final String FIELD_DM_EXTERNALCHARTDEFINITION = "externalChartDefinition";
	public static final String FIELD_DM_DEFAULTDATALOAD = "isDefault";
	public static final String FIELD_DM_DATALOADTYPE = "type";
	public static final String FIELD_DM_TARGETNAME = "targetName";
	public static final String FIELD_DM_SOURCENAME = "sourceName";
	public static final String FIELD_DM_INCLOADDATE = "incLoadDate";
	public static final String FIELD_DM_CONTINUOUS = "continuous";
	public static final String FIELD_DM_DTOFILTER = "dtoFilter";
	public static final String FIELD_DM_DTOSOURCEFILTER = "dtoSourceFilter";
	public static final String FIELD_DM_SORTBY = "sortBy";
	public static final String FIELD_DM_FIELDS = "fields";
	public static final String FIELD_DM_ACTIONUUID = "actionUUID";
	public static final String FIELD_DM_DATALOADS = "dataLoads";
	public static final String FIELD_DM_FCS = "fieldCollections";
	public static final String FIELD_DM_QUERIES = "queries";
	public static final String FIELD_DM_LASTDATAMODDATE = "lastDataModificationDate";
	public static final String FIELD_DM_ROWCOUNT = "rowCount";

	public static final String FIELD_DM_SUMMARY = "summary";
	public static final String FIELD_DM_SUMMARY_DISTINCT_VALUES_PREFIX = "distinctValuesFor_";
	public static final String FIELD_DM_SUMMARY_DISTINCT_VALUES_TOTALS_PREFIX = "distinctValuesTotalsFor_";
	public static final String FIELD_DM_SUMMARY_PROJECTIONS = "projections";
	public static final String FIELD_DM_SUMMARY_FORMULA = "formula";
	public static final String FIELD_DM_SUMMARY_MESSAGES = "messages";
    public static final String FIELD_DM_SUMMARY_SUM = "Sum";
	public static final String FIELD_DM_SUMMARY_MEAN = "Mean";
    public static final String FIELD_DM_SUMMARY_MIN = "Min";
	public static final String FIELD_DM_SUMMARY_MAX = "Max";
	public static final String FIELD_DM_SUMMARY_AVG = "Avg";
	public static final String FIELD_DM_SUMMARY_STD = "Std";
	public static final String FIELD_DM_SUMMARY_LRA = "LRa";
	public static final String FIELD_DM_SUMMARY_LRB = "LRb";
	public static final String FIELD_DM_SUMMARY_ERA = "ERa";
	public static final String FIELD_DM_SUMMARY_ERB = "ERb";
	public static final String FIELD_DM_SUMMARY_BINW = "BinW";
	public static final String FIELD_DM_SUMMARY_QUANTILEPREFIX = "Q";
	public static final String FIELD_DM_SUMMARY_HISTOGRAM = "Hist";
	public static final String FIELD_DM_SUMMARY_COUNT = "Count";
    public static final String FIELD_DM_SUMMARY_NA = "NA";                  // #missing values, i.e. nulls
    public static final String FIELD_DM_SUMMARY_DISTINCT = "Distinct";      // #distinct values

    public static final String FIELD_DMM_ISSIMPLEMODEL = "isSimpleModel";
    public static final String FIELD_DMM_ROOTMODELSOURCENAME = "rootModelSourceName";
	public static final String FIELD_DMM_MODELTYPE_UNIQUENAME = "modelTypeUN";
	public static final String FIELD_MODELTYPE_NATURE_UNIQUENAME = "modelNatureUN";
	public static final String FIELD_MODELTYPE_DEF = "modelTypeDef";
	public static final String FIELD_MODELTYPE_DEFJSON = "modelTypeDefJson";

	public static final String MODELNATURE_SEGMENTATION = "Segmentation";
	public static final String MODELNATURE_OPTIMIZATIONENGINE = "OptimizationEngine";
	public static final String MODELNATURE_GENERIC = "Generic";

    // generic configuration lob field
	public static final String FIELD_CONFIGURATION_JSON = "configurationJson";

	public static final String PARAM_DM_STATISTICS_MIN = "min";
	public static final String PARAM_DM_STATISTICS_MAX = "max";
	public static final String PARAM_DM_STATISTICS_QUANTILE_PREFIX = "q";
	public static final String PARAM_DM_STATISTICS_IQR_SUSPECTED_OUTLIERS = "iqrSO";
	public static final String PARAM_DM_STATISTICS_IQR_OUTLIERS = "iqrO";
	public static final String PARAM_DM_STATISTICS_IQR_LOWER_INNER_FENCE = "iqrLIF";
	public static final String PARAM_DM_STATISTICS_IQR_UPPER_INNER_FENCE = "iqrUIF";
	public static final String PARAM_DM_STATISTICS_IQR_LOWER_OUTER_FENCE = "iqrLOF";
	public static final String PARAM_DM_STATISTICS_IQR_UPPER_OUTER_FENCE = "iqrUOF";

	public static final String DM_STATISTICS_MIN_PROJ_ALIAS_SUFFIX = "_min";
	public static final String DM_STATISTICS_MAX_PROJ_ALIAS_SUFFIX = "_max";
	public static final String DM_STATISTICS_QUANTILE_PROJ_ALIAS_SUFFIX = "_q";
	public static final String DM_STATISTICS_IQR_SUSPECTED_OUTLIERS_PROJ_ALIAS_SUFFIX = "_iqr_so";
	public static final String DM_STATISTICS_IQR_OUTLIERS_PROJ_ALIAS_SUFFIX = "_iqr_o";
	public static final String DM_STATISTICS_IQR_LOWER_INNER_FENCE_PROJ_ALIAS_SUFFIX = "_iqr_lif";
	public static final String DM_STATISTICS_IQR_UPPER_INNER_FENCE_PROJ_ALIAS_SUFFIX = "_iqr_uif";
	public static final String DM_STATISTICS_IQR_LOWER_OUTER_FENCE_PROJ_ALIAS_SUFFIX = "_iqr_lof";
	public static final String DM_STATISTICS_IQR_UPPER_OUTER_FENCE_PROJ_ALIAS_SUFFIX = "_iqr_uof";

	public static final String DM_TIMEFIELD_PLACEHOLDER = "<timeField>";

	// PA formula element groups
	public static final String FORMULAELEMENTGROUP_DM_INIT = "init";
	public static final String FORMULAELEMENTGROUP_DM_ROW = "row";
	public static final String FORMULAELEMENTGROUP_DM_SUMMARY = "summary";

	// RM formula element groups
	public static final String FORMULAELEMENTGROUP_RM_AGREEMENT = "agreement";
	public static final String FORMULAELEMENTGROUP_RM_AGREEMENT_READONLY = "agreementReadOnly";
	public static final String FORMULAELEMENTGROUP_RM_REBATERECORD = "rebateRecord";

	// PA Distributed Calculation formula element groups
	public static final String FORMULAELEMENTGROUP_DIST_CALCULATION = "calculation";
	public static final String FORMULAELEMENTGROUP_DIST_CALCULATION_INIT = "calculation-init";
	public static final String FORMULAELEMENTGROUP_DIST_CALCULATION_SUMMARY = "calculation-summary";

	// DMM formula element groups
    public static final String FORMULAELEMENTGROUP_MODEL_DEFINITION = "definition";
    public static final String FORMULAELEMENTGROUP_MODEL_CALCULATION = "calculation";
	public static final String FORMULAELEMENTGROUP_MODEL_CALCULATION_INIT = "calculation-init";
	public static final String FORMULAELEMENTGROUP_MODEL_CALCULATION_SUMMARY = "calculation-summary";
    public static final String FORMULAELEMENTGROUP_MODEL_ANALYSIS = "analysis";
	public static final String FORMULAELEMENTGROUP_MODEL_EVAL = "evaluation";
    public static final String FORMULAELEMENTGROUP_MODEL_FINALIZATION = "finalization";
    public static final String FORMULAELEMENTGROUP_MODEL_RECORD = "record";

	// PA predefined ContextParam groups
	public static final String CONTEXTPARAMGROUP_FIXED = "fixed";
	public static final String CONTEXTPARAMGROUP_MAPPING = "mapping";
	public static final String CONTEXTPARAMGROUP_SCENARIO = "scenario";

	// configuration manager
	public static final String FIELD_CM_CONTENT = "content";
	public static final String FIELD_CM_SETTINGSNAMES = "settingsNames";

	// DTOs
	public static final String FIELD_CALCRESULT_WARNINGS = "warnings";
	public static final String FIELD_CALCRESULT_RESULTNAME = "resultName";
	public static final String FIELD_CALCRESULT_RESULTLABEL = "resultLabel";
	public static final String FIELD_CALCRESULT_LABELTRANSLATIONS = "labelTranslations";
	public static final String FIELD_CALCRESULT_RESULTDESCRIPTION = "resultDescription";
	public static final String FIELD_CALCRESULT_RESULT = "result";
    public static final String FIELD_CALCRESULT_RESULTMESSAGE = "resultMessage";
	public static final String FIELD_CALCRESULT_RESULTTYPE = "resultType";
	public static final String FIELD_CALCRESULT_ISOVERRIDABLE = "overridable";
	public static final String FIELD_CALCRESULT_ISOVERRIDDEN = "overridden";
	public static final String FIELD_CALCRESULT_SUFFIX = "suffix";
	public static final String FIELD_CALCRESULT_OVERRIDEVALUEOPTIONS = "overrideValueOptions";
	public static final String FIELD_CALCRESULT_ALERT_MESSAGE = "alertMessage";
	public static final String FIELD_CALCRESULT_RESULT_GROUP = "resultGroup";
	public static final String FIELD_CALCRESULT_ALERT_TYPE = "alertType";
	public static final String FIELD_CALCRESULT_CSS = "cssProperties";
	public static final String FIELD_CALCRESULT_RESULT_GENERATEDSAVEDCHART = "generatedSavedChart";
	public static final String FIELD_CALCRESULT_RESULT_FLEXCHART = "flexChart";
	public static final String FIELD_CALCRESULT_RESULT_FLEXCHART_BASETEMPLATE = "baseTemplateToUse";
	public static final String FIELD_CALCRESULT_RESULT_HIGHCHART_DEFINITION = "chartDefinition";
	public static final String FIELD_CALCRESULT_RESULT_HIGHCHART_DATATAB = "showDataTab";
	public static final String FIELD_CALCRESULT_RESULT_HIGHCHART_DATAHEADERS = "dataHeaders";
	public static final String FIELD_CALCRESULT_RESULT_HIGHCHART_RESULTMATRICES = "resultMatrixList";
	public static final String FIELD_CALCRESULT_RESULT_HIGHCHART_MODULES = "modulesList";
	public static final String FIELD_CALCRESULT_RESULT_HIGHMAP_MAPS = "mapsList";

    public static final String FIELD_CHARTCONTROLLEROPTIONS = "controllerOptions";
    public static final String FIELD_CHARTCONTROLLER_EDITGENERICFILTER = "showGenericFilter";
    public static final String FIELD_CHARTCONTROLLER_EDITDIMFILTERS = "showDimFilters";
    public static final String FIELD_CHARTCONTROLLER_DEFINEDIMFILTERS = "defineDimFilters";

	public static final String FIELD_CONTEXTPARAM_NAME = "name";
	public static final String FIELD_CONTEXTPARAM_VALUE = "value";
	public static final String FIELD_CONTEXTPARAM_LABEL = "label";
	public static final String FIELD_CONTEXTPARAM_LABELTRANSLATIONS = "labelTranslations";
	public static final String FIELD_CONTEXTPARAM_GROUP = "group";
	public static final String FIELD_CONTEXTPARAM_URL = "URL";
	public static final String FIELD_CONTEXTPARAM_CONFIG_DATATYPE = "dataType";
	public static final String FIELD_CONTEXTPARAM_CONFIG_INPUTTYPE = "inputType";
	public static final String FIELD_CONTEXTPARAM_CONFIG_FORMATTYPE = "formatType";
	public static final String FIELD_CONTEXTPARAM_CONFIG_FROM = "from";
	public static final String FIELD_CONTEXTPARAM_CONFIG_TO = "to";
	public static final String FIELD_CONTEXTPARAM_CONFIG_VALUES = "values";
	public static final String FIELD_CONTEXTPARAM_CONFIG_LABELS = "labels";
	public static final String FIELD_CONTEXTPARAM_CONFIG_TYPECODE = "typeCode";
	public static final String FIELD_CONTEXTPARAM_CONFIG_DM_FULL_NAME = "dmFullName";		// deprecated - use 'dmSourceName' from 2.9...
	public static final String FIELD_CONTEXTPARAM_CONFIG_DM_SOURCE_NAME = "dmSourceName";
	public static final String FIELD_CONTEXTPARAM_CONFIG_FILTERFORMULA = "filterFormula";
	public static final String FIELD_CONTEXTPARAM_CONFIG_TARGETPAGE = "targetPage";
	public static final String FIELD_CONTEXTPARAM_CONFIG_TARGETPAGESTATE = "targetPageState";
	public static final String FIELD_CONTEXTPARAM_CONFIG_TARGETPAGECOMPONENT = "targetPageComponent";
	public static final String FIELD_CONTEXTPARAM_CONFIG_PASEARCHABLE = "paSearchable";
	public static final String FIELD_CONTEXTPARAM_CONFIG_CALCCTX = "calculationContext";
	public static final String FIELD_CONTEXTPARAM_REQUIRED = "required";
	public static final String FIELD_CONTEXTPARAM_ALWAYS_EDITABLE = "alwaysEditable";

	public static final String FIELD_CONTEXTPARAM_CONFIG_FILTERFORMULA_NAME = "name";
	public static final String FIELD_CONTEXTPARAM_CONFIG_FILTERFORMULA_PARAM = "param";

	public static final String FIELD_SYNTAXCHECK_MESSAGE = "message";
	public static final String FIELD_SYNTAXCHECK_START = "startPosition";
	public static final String FIELD_SYNTAXCHECK_END = "endPosition";

	// Viewlog DTO
	public static final String FIELD_LOG_LEVEL = "level";
	public static final String FIELD_LOG_TIMESTAMP = "timestamp";
	public static final String FIELD_LOG_THREADNAME = "threadName";
	public static final String FIELD_LOG_LOGGERNAME = "loggerName";
	public static final String FIELD_LOG_USERNAME = "userName";
	public static final String FIELD_LOG_URI = "requestURI";
	public static final String FIELD_LOG_MARKER = "marker";
	public static final String FIELD_LOG_CLIENTIP = "clientIP";
	public static final String FIELD_LOG_DETAILS = "details";
	public static final String FIELD_LOG_TARGETNAME = "targetObjectName";
	public static final String FIELD_LOG_TARGETTYPE = "targetObjectType";
	public static final String FIELD_LOG_ACTION = "action";

	// JobStatusTracker
	public static final String FIELD_JOBSTATUSTRACKER_PROGRESS = "progress";
	public static final String FIELD_JOBSTATUSTRACKER_MESSAGES = "messages";
	public static final String FIELD_JOBSTATUSTRACKER_THREADUUID = "threadUUID";
	public static final String FIELD_JOBSTATUSTRACKER_TYPE = "trackerType";
	public static final String FIELD_JOBSTATUSTRACKER_NODE = "processingNode";
	public static final String FIELD_JOBSTATUSTRACKER_TARGET = "targetObject";
	public static final String FIELD_JOBSTATUSTRACKER_CONCKEY = "concurrencyKey";
	public static final String FIELD_JOBSTATUSTRACKER_CALCCTX = "calculationContext";
	public static final String FIELD_JOBSTATUSTRACKER_START = "processingStart";
	public static final String FIELD_JOBSTATUSTRACKER_END = "processingEnd";
	public static final String FIELD_JOBSTATUSTRACKER_JOBNAME = "jobName";
	public static final String FIELD_JOBSTATUSTRACKER_CANCELREQUESTED = "cancelRequested";
	public static final String PARAM_NOTIFY_USER_WHEN_FINISHED = "notifyWhenFinished";

	// Data import/export
	public static final String FIELD_CLUSTER  = "cluster";
	public static final String FIELD_NODE  = "node";
	public static final String FIELD_ARCHIVENAME  = "archiveName";
	public static final String FIELD_SOURCEARCHIVE  = "sourceArchive";
	public static final String FIELD_ARCHIVETYPE  = "archiveType";
	public static final String FIELD_KEEPUNKNOWNMETALINKS  = "keepUnknownMetaLinks";

	// CLIC Mass Update
	public static final String FIELD_MASS_UPDATE_TYPE = "massUpdateType";

	// Job Trigger
	public static final String FIELD_JOBTRIGGER_JST_ID = "jstId";
	public static final String FIELD_JOBTRIGGER_STATUS = "status";
	public static final String FIELD_JOBTRIGGER_PROGRESS = "progress";
	public static final String FIELD_JOBTRIGGER_LOG_EVENTS = "logEvents";
	public static final String FIELD_JOBTRIGGER_CALCULATION_MESSAGES = "calculationMessages";


	/**
	 *
	 * OTHER
	 *
	 */

	public static final String DEFAULT_HEADERTYPE_UNIQUENAME = "__DEFAULT__";
	public static final String GROOVY_LIBRARY_UNIQUENAME = "__LIBRARY__";

	public static final String CONTEXTPARAM_NAME_PRODUCTSKU = "ProductSKU";
	public static final String CONTEXTPARAM_NAME_CUSTOMER = "Customer";
	public static final String CONTEXTPARAM_NAME_CUSTOMERGROUP = "CustomerGroup";
	public static final String CONTEXTPARAM_NAME_PRODUCTGROUP = "ProductGroup";
	public static final String CONTEXTPARAM_NAME_STARTDATE = "StartDate";
	public static final String CONTEXTPARAM_NAME_ENDDATE = "EndDate";
	public static final String CONTEXTPARAM_NAME_PAYOUTDATE = "PayoutDate";
	public static final String CONTEXTPARAM_NAME_CONTEXTSKUSET = "ContextSkuSet";
	public static final String CONTEXTPARAM_NAME_ITEM = "Item";
	public static final String CONTEXTPARAM_NAME_CO_TYPEDID = "CalculableObjectTypedId";
	public static final String CONTEXTPARAM_NAME_CO_ITEMFILTER = "CalculableObjectItemFilter";
	public static final String CONTEXTPARAM_NAME_CALCULATIONSTEP = "CalculationStep";
	public static final String CONTEXTPARAM_NAME_CALCULATIONITEM = "CalculationItem";
	public static final String CONTEXTPARAM_NAME_SELLER = "Seller";
	public static final String CONTEXTPARAM_CONFIG_INPUTTYPE_RANGE = "range";
	public static final String CONTEXTPARAM_CONFIG_INPUTTYPE_DROPDOWN = "drop-down";
	public static final String CONTEXTPARAM_CONFIG_DATATYPE_STRING = "text";
	public static final String CONTEXTPARAM_CONFIG_DATATYPE_REAL = "float";
	public static final String CONTEXTPARAM_CONFIG_DATATYPE_INTEGER = "integer";
	public static final String CONTEXTPARAM_CONFIG_DATATYPE_DATE = "date";
	public static final String CONTEXTPARAM_CONFIG_DATATYPE_TIME = "time";
	public static final String CONTEXTPARAM_CONFIG_DATATYPE_DATETIME = "datetime";
	public static final String CONTEXTPARAM_CONFIG_DATATYPE_PRODUCT = "product";
	public static final String CONTEXTPARAM_CONFIG_DATATYPE_CUSTOMER = "customer";


	public static final String[] PRICEGRID_DEFAULT_FIELDS = {FIELD_CI_PREVIOUSPRICE,
															FIELD_PGI_PREVIOUSPRICEDATE,
															FIELD_PGI_PRICECHANGEABS_PREV,
															FIELD_PGI_PRICECHANGEPCT_PREV,
															FIELD_PGI_ACTIVEPRICE,
															FIELD_PGI_ACTIVEPRICEDATE,
															FIELD_CI_PRICECHANGEABS,
															FIELD_CI_PRICECHANGEPCT,
															FIELD_CI_RESULTPRICE,
															FIELD_CI_MANUALPRICE,
															FIELD_DENIALDATE
	};

	public static final int CALCULABLELINESTATUS_OK = 0;
	public static final int CALCULABLELINESTATUS_ERROR = 1;
	public static final int CALCULABLELINESTATUS_WARNING = 2;
	public static final int CALCULABLELINESTATUS_REDALERT = 4;
	public static final int CALCULABLELINESTATUS_YELLOWALERT = 8;
	public static final int CALCULABLELINESTATUS_CRITICALALERT = 16;

	public static final int CALCULABLELINE_EDITABILITY_NORESTRICTION = 0;
	public static final int CALCULABLELINE_EDITABILITY_READ_ONLY = 1;
	public static final int CALCULABLELINE_EDITABILITY_NO_DELETE = 2;

	public static final long ARTIFICIAL_ROOT_PARENTID = -1L;
	public static final long ARTIFICIAL_ROOT_NODEID = 0L;
	public static final String ARTIFICIAL_ROOT_LABELPREFIX = "treeLabel_";

	// saved chart representation
	public static final String CHARTDEF_SERIES_GRIDPREFERENCES = "seriesGridPreferences";
	public static final String CHARTDEF_SERIES_X = "x";
	public static final String CHARTDEF_SERIES_Y = "y";
	public static final String CHARTDEF_SERIES_Z = "z";
	public static final String CHARTDEF_SERIES_GROUPBY = "groupBy";
	public static final String CHARTDEF_SERIES_BANDBY = "bandBy";
	public static final String CHARTDEF_SERIES_BANDBY_STATE = "bandByLegend";
	public static final String CHARTDEF_SERIES_SHOW_BANDBY_LEGEND = "showBandByLegend";
	public static final String CHARTDEF_SERIES_BUBBLESIZE = "bubbleSize";
	public static final String CHARTDEF_SERIES_AGGREGATIONFORMULACONTROLLER = "calculatedFieldFormulaControllerState";
	public static final String CHARTDEF_SERIES_AGGREGATIONFORMULACONTROLLER_AGGREGATIONFORMULA = "aggregationFormula";
	public static final String CHARTDEF_SERIES_AGGREGATIONFORMULACONTROLLER_AGGREGATIONFORMULAPARAMS = "aggregationFormulaParams";
	public static final String CHARTDEF_SERIES_NONAGGREGATIONFORMULACONTROLLER = "calculatedFieldNonAggrFormulaControllerState";
	public static final String CHARTDEF_SERIES_NONAGGREGATIONFORMULACONTROLLER_NONAGGREGATIONFORMULA = "nonAggregationFormula";
	public static final String CHARTDEF_SERIES_NONAGGREGATIONFORMULACONTROLLER_NONAGGREGATIONFORMULAPARAMS = "nonAggregationFormulaParams";
	public static final String CHARTDEF_SERIES_DIMFILTERS = "dimFilters";
	public static final String CHARTDEF_SERIES_DIMFILTER_FIELDNAME = "fieldName";
	public static final String CHARTDEF_SERIES_DIMFILTER_FIELDVALUE = "fieldValue";
	public static final String CHARTDEF_SERIES_DIMFILTER_SYNCED = "fieldSynced";
	public static final String CHARTDEF_SERIES_FILTER = "lineLevelFilter";
	public static final String CHARTDEF_SERIES_PGFILTER = "productsFilter";
	public static final String CHARTDEF_SERIES_CGFILTER = "customersFilter";
	public static final String CHARTDEF_SERIES_AGGRFILTER = "aggregateFilter";
	public static final String CHARTDEF_SERIES_ADDITIONALMEASURES = "additionalMeasures";
	public static final String CHARTDEF_SERIES_ADDITIONALMEASURE_ONZAXIS = "onZAxis";
	public static final String CHARTDEF_SERIES_ADDITIONALMEASURE_FORMULA = "aggrFormula";
	public static final String CHARTDEF_SERIES_ADDITIONALMEASURE_BOXPLOTFORMULA = "boxplotNonAggrFormula";
	public static final String CHARTDEF_SERIES_LIMITTO = "rowLimit";
	public static final String CHARTDEF_SERIES_FORMULAPARAMS = "formulaParams";
	public static final String CHARTDEF_SERIES_FORMULA_NAME = "formulaName";
	public static final String CHARTDEF_SERIES_FORMULA_TARGETDATE = "formulaTargetDate";
	public static final String CHARTDEF_SERIES_FORMULA_INPUTPARAMS = "formulaInputParams";
	public static final String CHARTDEF_SERIES_FORMULA_SELECTEDOUTPUTS = "formulaSelectedOutputs";
	public static final String CHARTDEF_SERIES_WATERFALLCOLUMN_NAME = "name";
	public static final String CHARTDEF_SERIES_WATERFALLCOLUMN_TYPE = "type";
	public static final String CHARTDEF_SERIES_WATERFALLCOLUMN_VALUE = "value";
	public static final String CHARTDEF_SERIES_WATERFALLCOLUMNS = "records";
	public static final String CHARTDEF_SERIES_FROM_DATE = "fromDate";
	public static final String CHARTDEF_SERIES_TO_DATE = "toDate";
	public static final String CHARTDEF_SERIES_COMPARISON_OFFSET = "comparisonOffset";
	public static final String CHARTDEF_SERIES_NUMBEROFBINS = "numberOfBins";
	public static final String CHARTDEF_SERIES_GROUPBYDIMS = "groupByDims";
	public static final String CHARTDEF_SERIES_EXPRESSION_EXPRESSION = "expression";
	public static final String CHARTDEF_SERIES_EXPRESSION_DESCRIPTION = "description";
	public static final String CHARTDEF_SERIES_EXPRESSION_DEFAULTVALUE = "defaultValue";
	public static final String CHARTDEF_SERIES_LIMITTO_MEASURE = "measure";
	public static final String CHARTDEF_SERIES_LIMITTO_TOPBOTTOM = "topBottom";
	public static final String CHARTDEF_SERIES_LIMITTO_VALUE = "value";
	public static final String CHARTDEF_SERIES_LIMITTO_UNIT = "units";
	public static final String CHARTDEF_SERIES_LIMITTO_HIDEOTHER = "hideOther";
	public static final String CHARTDEF_SERIES_SHOW_BOXPLOT = "showBoxplot";
	public static final String CHARTDEF_SERIES_BOXPLOT_AXIS_ALIAS_PREFIX = "bplot_";
	public static final String CHARTDEF_SERIES_Y_BOXPLOT = CHARTDEF_SERIES_BOXPLOT_AXIS_ALIAS_PREFIX + CHARTDEF_SERIES_Y;
	public static final String CHARTDEF_SERIES_WHISKER_TYPE = "whiskerType";
	public static final String CHARTDEF_SERIES_NORMALIZATION = "normalization";
	public static final String CHARTDEF_SERIES_COLOR = "color";

	// 2.8/LIIT: all of the TREND LINE constant names had 'LINEAR' in them in 2.7; we have to leave the string values for backwards compatibility with saved charts
	public static final String CHARTDEF_SERIES_SHOW_TREND_LINE = "showLinearTrendLine";
	public static final String CHARTDEF_SERIES_TREND_LINE_LABEL = "linearTrendLineLabel";
	public static final String CHARTDEF_SERIES_TREND_LINE_TYPE = "trendLineType";		// linear or exponential in 2.8 (LIIT)
	public static final String CHARTDEF_SERIES_SHOW_TREND_LINE_IN_LEGEND = "showLinearTrendLineInLegend";
	public static final String CHARTDEF_SERIES_TREND_LINE_HIDE_DATA_LABELS = "linearTrendLineHideDataLabels";
	public static final String CHARTDEF_SERIES_TREND_LINE_COLOR = "linearTrendLineColor";

	public static final String CHARTDEF_SERIES_COLOR_AXIS_TYPE = "colorAxisType";
	public static final String CHARTDEF_SERIES_COLOR_AXIS_TYPE_RANGED = "colorAxisTypeRanged";
	public static final String CHARTDEF_SERIES_COLOR_AXIS_TYPE_INTERPOLATED = "colorAxisTypeInterpolated";
	public static final String CHARTDEF_SERIES_COMPARISON_DIM_ALIAS = "joinKey";
	public static final String CHARTDEF_OPTIONS_COMPARISON_TYPE = "comparisonType";
	public static final String CHARTDEF_OPTIONS_XMIN = "xMin";
	public static final String CHARTDEF_OPTIONS_XMAX = "xMax";
	public static final String CHARTDEF_OPTIONS_XMINDATE = "xMinDate";
	public static final String CHARTDEF_OPTIONS_XMAXDATE = "xMaxDate";
	public static final String CHARTDEF_OPTIONS_YMIN = "yMin";
	public static final String CHARTDEF_OPTIONS_YMAX = "yMax";
	public static final String CHARTDEF_OPTIONS_ZMIN = "zMin";
	public static final String CHARTDEF_OPTIONS_ZMAX = "zMax";
	public static final String CHARTDEF_OPTIONS_XLOG = "xLog";
	public static final String CHARTDEF_OPTIONS_YLOG = "yLog";
	public static final String CHARTDEF_OPTIONS_ZLOG = "zLog";
	public static final String CHARTDEF_OPTIONS_MARKER = "marker";
	public static final String CHARTDEF_OPTIONS_MARKER_X = "x";
	public static final String CHARTDEF_OPTIONS_MARKER_Y = "y";
	public static final String CHARTDEF_OPTIONS_MAXPOINTS = "maxPoints";
	public static final String CHARTDEF_OPTIONS_LEGACY_COMPARISON = "legacyComparison";
	public static final String CHARTDEF_OPTIONS_BPLOTAXISLABEL = "bplotLabel";
	public static final String CHARTDEF_OPTIONS_BPLOTAXISMIN = "bplotMin";
	public static final String CHARTDEF_OPTIONS_BPLOTAXISMAX = "bplotMax";
	public static final String CHARTDEF_OPTIONS_VERTICALLAYOUT = "verticalLayout";
	public static final String CHARTDEF_OPTIONS_DISABLE_DRILLDOWN = "disableDrilldown";
	public static final String CHARTDEF_OPTIONS_DISABLE_ZOOM = "disableZoom";
	public static final String CHARTDEF_OPTIONS_DISCRETIZATION = "discretization";
	public static final String CHARTDEF_OPTIONS_NOGRIDDISCRETIZATION = "disableGridDiscretization";
	public static final String CHARTDEF_OPTIONS_INITIAL_DATA_GROUPING = "initialDataGrouping";

	public static final String CHARTDEF_EVENTS_NAME = "eventName";
	public static final String CHARTDEF_EVENTS_TYPE = "eventType";
	public static final String CHARTDEF_EVENTS_SUBTYPE = "eventSubtype";
	public static final String CHARTDEF_EVENTS_PARAM = "eventParam";

	public static final String CHARTDEF_EVENTS_TYPE_CLICK = "onClick";
	public static final String CHARTDEF_EVENTS_TYPE_ROWCLICK = "onRowClick";
	public static final String CHARTDEF_EVENTS_TYPE_CELLCLICK = "onCellClick";

	public static final String CHARTDEF_AUXLINE_STEPPEDLINE_RECORDS = "records";

	// Start Page

    public static final String SYSTEMPORTLET_PRICEGRIDS = "priceGrid";

    public static final String SYSTEMPORTLET_PRICELISTS = "pricelist";

    public static final String SYSTEMPORTLET_REBATES = "rebateManager";

    public static final String SYSTEMPORTLET_QUOTES = "priceShop";

    public static final String SYSTEMPORTLET_CONTRACTS = "promotionManager";

    public static final String SYSTEMPORTLET_CLAIMS = "claimManager";

    public static final String SYSTEMPORTLET_CHARTS = "savedCharts";

    public static final String SYSTEMPORTLET_DASHBOARDS = "dashboard";

    public static final String SYSTEMPORTLET_QUICKSEARCH = "quicksearch";

    public static final String SYSTEMPORTLET_TODOS = "toDo";

    public static final String SYSTEMPORTLET_PENDINGAPPROVALS = "workflow";

    public static final String SYSTEMPORTLET_PENDINGCREATIONWFS = "pendingCreationWorkflow";

    public static final String CMD_OE_UPDATE_STATUS = "optimizationengine.updatestatus";

    public static final String CMD_PO_MODEL_FORMULA_PARAMS = "optimization.modelformulaparams";
    public static final String CMD_PO_MODEL_FORMULA_EXEC = "optimization.modelformulaexec";
    public static final String CMD_PO_MODEL_CALC_EXEC = "optimization.modelcalcexec";
    public static final String CMD_PO_MODEL_CALC_STATUS = "optimization.modelcalcstatus";

	public static final String ENV_CONTROLLED_REMOTELY = "CONTROLLED_REMOTELY";

	private PriceFxInterface() {}

}
