package net.pricefx.common.apibuilder.chart;

import java.math.BigDecimal;
import java.util.Date;

import net.pricefx.common.api.chart.ChartType;
import net.pricefx.common.api.chart.LimitPosition;
import net.pricefx.common.api.chart.LimitType;
import net.pricefx.common.api.chart.SeriesType;
import net.pricefx.common.api.chart.WhiskerType;
import net.pricefx.common.apibuilder.AbstractAdditionalMeasure;
import net.pricefx.common.apibuilder.AbstractBuilder;
import net.pricefx.common.apibuilder.AbstractOptions;
import net.pricefx.common.apibuilder.AbstractSeries;
import net.pricefx.common.apibuilder.IdGenerator;
import net.pricefx.common.apibuilder.Invocations;
import net.pricefx.common.apibuilder.MethodInvocation;
import net.pricefx.common.apibuilder.ObjectIdentity;

public class TimeSeriesChart extends AbstractBuilder {

	public TimeSeriesChart(String instanceId, String classId, ObjectIdentity parentChartObjectIdentity, IdGenerator idGenerator, Invocations<MethodInvocation> invocations) {
		super(instanceId, classId, idGenerator, invocations);
	}

	private TimeSeriesOptions options;
	private Dictionary<TimeSeriesChart> dictionary;
	
	public TimeSeriesSeries addSeries() {
		String id = addInvocation("addSeries");
		return new TimeSeriesSeries(this, id, "Series", idGenerator, invocations);
	}
	
	public TimeSeriesOptions getOptions() {
		String id = addInvocation("getOptions");
		if (options == null) 
			options = new TimeSeriesOptions(this, id, "Options", idGenerator, invocations);
		return options;
	}
	
	public AuxLine<TimeSeriesChart> addAuxLine() {
		String id = addInvocation("addAuxLine");
		return new AuxLine<TimeSeriesChart>(this, id, "AuxLine");
	}
	
	public Dictionary<TimeSeriesChart> getDictionary() {
		String id = addInvocation("getDictionary");
		if (dictionary == null) 
			dictionary = new Dictionary<>(this, id, "Dictionary");
		return dictionary;
	}
	
	@Override
	public ChartBuilderResult build() {
		addInvocation(METHOD_BUILD);

		ChartBuilderResult r = new ChartBuilderResult();
		r.invocations = invocations.get();
		r.additionalInfo = ChartType.TIMESERIES;
		return r;
	}
	
	public static class TimeSeriesSeries extends AbstractSeries<TimeSeriesChart,TimeSeriesSeries> {

		public TimeSeriesSeries(TimeSeriesChart backLink, String instanceId, String classId, IdGenerator idGenerator, Invocations<MethodInvocation> invocations) {
			super(instanceId, classId, backLink, idGenerator, invocations);
		}
		
		public TimeSeriesSeries setHideDataLabels(Boolean hideDataLabels) {

			addInvocation("setHideDataLabels",hideDataLabels);
			return this;
		}
		
		public LimitToMeasure<TimeSeriesSeries> setLimitTo(LimitPosition limitPosition, BigDecimal amount, LimitType limitType) {
			
			String id = addInvocation("setLimitTo",limitPosition, amount, limitType);
			return new LimitToMeasure<TimeSeriesSeries>(this, id, "LimitToMeasure");
		}
		
		public TimeSeriesSeries setAxisX(String axisX) {
			
			addInvocation("setAxisX",axisX);
			return this;
		}
		
		public AggrFieldAxis<TimeSeriesSeries> setAxisY(String axisY) {
			
			String id = addInvocation("setAxisY",axisY);
			return new AggrFieldAxis<TimeSeriesSeries>(this, id, "AxisY");
		}

		public TimeSeriesSeries setFromDate(Date fromDate) {

			addInvocation("setFromDate",fromDate);
			return this;
		}
		
		public TimeSeriesSeries setToDate(Date toDate) {

			addInvocation("setToDate",toDate);
			return this;
		}
		
		public TimeSeriesSeries setComparisonPeriod(BigDecimal comparisonPeriod) {

			addInvocation("setComparisonPeriod",comparisonPeriod);
			return this;
		}
		
		public TimeSeriesSeries setType(SeriesType seriesType) {

			addInvocation("setType",seriesType);
			return this;
		}
		
		public TimeSeriesSeries setShowBoxplot(Boolean showBoxplot) {

			addInvocation("setShowBoxplot",showBoxplot);
			return this;
		}
		
		public NonAggrFieldAxis<TimeSeriesSeries> setBoxplotAxis() {

			String id = addInvocation("setBoxplotAxis");
			return new NonAggrFieldAxis<TimeSeriesSeries>(this, id, "BoxplotAxis");
		}
		
		public TimeSeriesSeries setWhisker(WhiskerType whiskerType) {

			addInvocation("setWhisker",whiskerType);
			return this;
		}
		
		public TrendLine<TimeSeriesSeries> withTrendLine() {
			
			String id = addInvocation("withTrendLine");
			return new TrendLine<TimeSeriesSeries>(this, id, "TrendLine");
		}
		
		public TimeSeriesAdditionalMeasure<TimeSeriesSeries> addAdditionalMeasure() {
			
			String id = addInvocation("addAdditionalMeasure");
			return new TimeSeriesAdditionalMeasure<TimeSeriesSeries>(this, id, "AdditionalMeasure", idGenerator, invocations);
		}
		
		public Formula<TimeSeriesSeries> setFormula() {
			
			String id = addInvocation("setFormula");
			return new Formula<TimeSeriesSeries>(this, id, "Formula");
		}
		
		public TimeSeriesSeries setGeneratedQueryDto(String generatedQueryDto) {
			
			addInvocation("setGeneratedQueryDto",generatedQueryDto);
			return this;
		}
	}
	
	public static class TimeSeriesOptions extends AbstractOptions<TimeSeriesChart,TimeSeriesOptions> {

		public TimeSeriesOptions(TimeSeriesChart backLink, String instanceId, String classId, IdGenerator idGenerator, Invocations<MethodInvocation> invocations) {
			super(instanceId, classId, backLink, idGenerator, invocations);
		}

		
		public TimeSeriesOptions setLegacyComparisonMode(Boolean legacyComparisonMode) {

			addInvocation("setLegacyComparisonMode",legacyComparisonMode);
			return this;
		}

		
		public TimeSeriesOptions setBoxplotAxisLabel(String boxplotAxisLabel) {
			addInvocation("setBoxplotAxisLabel",boxplotAxisLabel);
			return this;
		}
		
		public TimeSeriesOptions setBoxplotAxisMin(BigDecimal boxplotAxisMin) {
			addInvocation("setBoxplotAxisMin",boxplotAxisMin);
			return this;
		}
		
		public TimeSeriesOptions setBoxplotAxisMax(BigDecimal boxplotAxisMax) {
			addInvocation("setBoxplotAxisMax",boxplotAxisMax);
			return this;
		}
		
		
	}
	
	public static class TimeSeriesAdditionalMeasure<ATTACHEDTO extends ObjectIdentity> extends AbstractAdditionalMeasure<ATTACHEDTO,TimeSeriesAdditionalMeasure<ATTACHEDTO>> {

		public TimeSeriesAdditionalMeasure(ATTACHEDTO attachedTo, String instanceId, String classId, IdGenerator idGenerator, Invocations<MethodInvocation> invocations) {
			super(instanceId, classId, attachedTo, idGenerator, invocations);
		}

		public Expression<TimeSeriesAdditionalMeasure<ATTACHEDTO>> withExpression() { 

			String id = addInvocation("withExpression");
			return new Expression<TimeSeriesAdditionalMeasure<ATTACHEDTO>>(this, id, "Expression");
		}
		
		public TimeSeriesAdditionalMeasure<ATTACHEDTO> withBoxplotField() { 

			addInvocation("withBoxplotField");
			return this;
		}
		
		public Expression<TimeSeriesAdditionalMeasure<ATTACHEDTO>> withBoxplotExpression() { 
			
			String id = addInvocation("withBoxplotExpression");
			return new Expression<TimeSeriesAdditionalMeasure<ATTACHEDTO>>(this, id, "BoxplotExpression");
		}
		
	}
	
}