package net.pricefx.server.dto.calculation;

import net.pricefx.common.api.CalculationResultType;
import net.pricefx.domain.RebateRecord;

import com.fasterxml.jackson.annotation.JsonProperty;

public class ResultRebateRecord implements ComplexCalculationResult {

    private static final long serialVersionUID = -2194620977066033415L;
    
    @JsonProperty public String uniqueName;
	@JsonProperty public String name;
	@JsonProperty public String rebateRecordSetLabel; 
	@JsonProperty public String description;
	@JsonProperty public String sourceId;		// the ID of the rebate agreement this record belongs to
	
	protected ResultRebateRecord() {}
	
	public ResultRebateRecord(final RebateRecord rebateRecord) {
		uniqueName = rebateRecord.getUniqueName();
		name = rebateRecord.getName();
		rebateRecordSetLabel = rebateRecord.getRebateRecordSetLabel();
		sourceId = rebateRecord.getSourceId();
	}
	
	@Override
	public String getResultType() {
		return CalculationResultType.REBATERECORD.name();
	}

	public String getDescription() {
		if (description == null){
			boolean hasName = name != null && !"".equals(name);
			boolean hasSet = rebateRecordSetLabel != null && !"Default".equals(rebateRecordSetLabel);
			if (hasName && hasSet){
				description = String.format("%s: %s (%s)", uniqueName, name, rebateRecordSetLabel);
			}
			else if (hasName){
				description = String.format("%s: %s", uniqueName, name);
			}
			else if (hasSet){
				description = String.format("%s: %s", uniqueName, rebateRecordSetLabel);
			}
			else description = new String(uniqueName);
		}
		return description;
	}

	@Override
	public String toString() {
		return getDescription();
	}
	
}